@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -55,29 +55,39 @@ struct _mongoc_apm_command_started_t {
    int64_t operation_id;
    const mongoc_host_list_t *host;
    uint32_t server_id;
+   bson_oid_t service_id;
+   int64_t server_connection_id;
    void *context;
 };
 
 struct _mongoc_apm_command_succeeded_t {
    int64_t duration;
-   const bson_t *reply;
+   bson_t *reply;
+   bool reply_owned;
    const char *command_name;
+   const char *database_name;
    int64_t request_id;
    int64_t operation_id;
    const mongoc_host_list_t *host;
    uint32_t server_id;
+   bson_oid_t service_id;
+   int64_t server_connection_id;
    void *context;
 };
 
 struct _mongoc_apm_command_failed_t {
    int64_t duration;
    const char *command_name;
+   const char *database_name;
    const bson_error_t *error;
-   const bson_t *reply;
+   bson_t *reply;
+   bool reply_owned;
    int64_t request_id;
    int64_t operation_id;
    const mongoc_host_list_t *host;
    uint32_t server_id;
+   bson_oid_t service_id;
+   int64_t server_connection_id;
    void *context;
 };
 
@@ -125,6 +135,7 @@ struct _mongoc_apm_topology_closed_t {
 struct _mongoc_apm_server_heartbeat_started_t {
    const mongoc_host_list_t *host;
    void *context;
+   bool awaited;
 };
 
 struct _mongoc_apm_server_heartbeat_succeeded_t {
@@ -132,6 +143,7 @@ struct _mongoc_apm_server_heartbeat_succeeded_t {
    const bson_t *reply;
    const mongoc_host_list_t *host;
    void *context;
+   bool awaited;
 };
 
 struct _mongoc_apm_server_heartbeat_failed_t {
@@ -139,6 +151,7 @@ struct _mongoc_apm_server_heartbeat_failed_t {
    const bson_error_t *error;
    const mongoc_host_list_t *host;
    void *context;
+   bool awaited;
 };
 
 void
@@ -150,12 +163,16 @@ mongoc_apm_command_started_init (mongoc_apm_command_started_t *event,
                                  int64_t operation_id,
                                  const mongoc_host_list_t *host,
                                  uint32_t server_id,
+                                 const bson_oid_t *service_id,
+                                 int64_t server_connection_id,
+                                 bool *is_redacted, /* out */
                                  void *context);
 
 void
 mongoc_apm_command_started_init_with_cmd (mongoc_apm_command_started_t *event,
                                           struct _mongoc_cmd_t *cmd,
                                           int64_t request_id,
+                                          bool *is_redacted, /* out */
                                           void *context);
 
 void
@@ -166,10 +183,14 @@ mongoc_apm_command_succeeded_init (mongoc_apm_command_succeeded_t *event,
                                    int64_t duration,
                                    const bson_t *reply,
                                    const char *command_name,
+                                   const char *database_name,
                                    int64_t request_id,
                                    int64_t operation_id,
                                    const mongoc_host_list_t *host,
                                    uint32_t server_id,
+                                   const bson_oid_t *service_id,
+                                   int64_t server_connection_id,
+                                   bool force_redaction,
                                    void *context);
 
 void
@@ -179,17 +200,31 @@ void
 mongoc_apm_command_failed_init (mongoc_apm_command_failed_t *event,
                                 int64_t duration,
                                 const char *command_name,
+                                const char *database_name,
                                 const bson_error_t *error,
                                 const bson_t *reply,
                                 int64_t request_id,
                                 int64_t operation_id,
                                 const mongoc_host_list_t *host,
                                 uint32_t server_id,
+                                const bson_oid_t *service_id,
+                                int64_t server_connection_id,
+                                bool force_redaction,
                                 void *context);
 
 void
 mongoc_apm_command_failed_cleanup (mongoc_apm_command_failed_t *event);
 
+/**
+ * @brief Determine whether the given command-related message is a "sensitive
+ * command."
+ *
+ * @param command_name The name of the command being checked
+ * @param body The body of the command request, reply, or failure.
+ */
+bool
+mongoc_apm_is_sensitive_command_message (const char *command_name, const bson_t *body);
+
 BSON_END_DECLS
 
 #endif /* MONGOC_APM_PRIVATE_H */
