@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -21,6 +21,7 @@
 #include "mongoc-error.h"
 #include "mongoc-buffer-private.h"
 #include "mongoc-trace-private.h"
+#include <common-cmp-private.h>
 
 
 #undef MONGOC_LOG_DOMAIN
@@ -36,8 +37,7 @@ make_space_for (mongoc_buffer_t *buffer, size_t data_size)
 {
    if (buffer->len + data_size > buffer->datalen) {
       buffer->datalen = bson_next_power_of_two (buffer->len + data_size);
-      buffer->data = (uint8_t *) buffer->realloc_func (
-         buffer->data, buffer->datalen, buffer->realloc_data);
+      buffer->data = (uint8_t *) buffer->realloc_func (buffer->data, buffer->datalen, buffer->realloc_data);
    }
 }
 
@@ -56,11 +56,8 @@ make_space_for (mongoc_buffer_t *buffer, size_t data_size)
  * cleaning up the data structure.
  */
 void
-_mongoc_buffer_init (mongoc_buffer_t *buffer,
-                     uint8_t *buf,
-                     size_t buflen,
-                     bson_realloc_func realloc_func,
-                     void *realloc_data)
+_mongoc_buffer_init (
+   mongoc_buffer_t *buffer, uint8_t *buf, size_t buflen, bson_realloc_func realloc_func, void *realloc_data)
 {
    BSON_ASSERT_PARAM (buffer);
    BSON_ASSERT (buflen || !buf);
@@ -129,9 +126,7 @@ _mongoc_buffer_clear (mongoc_buffer_t *buffer, bool zero)
 
 
 bool
-_mongoc_buffer_append (mongoc_buffer_t *buffer,
-                       const uint8_t *data,
-                       size_t data_size)
+_mongoc_buffer_append (mongoc_buffer_t *buffer, const uint8_t *data, size_t data_size)
 {
    uint8_t *buf;
 
@@ -171,11 +166,8 @@ _mongoc_buffer_append (mongoc_buffer_t *buffer,
  * Returns: true if successful; otherwise false and @error is set.
  */
 bool
-_mongoc_buffer_append_from_stream (mongoc_buffer_t *buffer,
-                                   mongoc_stream_t *stream,
-                                   size_t size,
-                                   int64_t timeout_msec,
-                                   bson_error_t *error)
+_mongoc_buffer_append_from_stream (
+   mongoc_buffer_t *buffer, mongoc_stream_t *stream, size_t size, int64_t timeout_msec, bson_error_t *error)
 {
    uint8_t *buf;
    ssize_t ret;
@@ -194,19 +186,18 @@ _mongoc_buffer_append_from_stream (mongoc_buffer_t *buffer,
 
    BSON_ASSERT ((buffer->len + size) <= buffer->datalen);
 
-   if (BSON_UNLIKELY (!bson_in_range_signed (int32_t, timeout_msec))) {
+   if (BSON_UNLIKELY (!mcommon_in_range_signed (int32_t, timeout_msec))) {
       // CDRIVER-4589
       bson_set_error (error,
                       MONGOC_ERROR_STREAM,
                       MONGOC_ERROR_STREAM_SOCKET,
-                      "timeout_msec value %" PRId64
-                      " exceeds supported 32-bit range",
+                      "timeout_msec value %" PRId64 " exceeds supported 32-bit range",
                       timeout_msec);
       RETURN (false);
    }
 
    ret = mongoc_stream_read (stream, buf, size, size, (int32_t) timeout_msec);
-   if (bson_cmp_not_equal_su (ret, size)) {
+   if (mcommon_cmp_not_equal_su (ret, size)) {
       bson_set_error (error,
                       MONGOC_ERROR_STREAM,
                       MONGOC_ERROR_STREAM_SOCKET,
@@ -233,11 +224,8 @@ _mongoc_buffer_append_from_stream (mongoc_buffer_t *buffer,
  * Returns: The number of buffered bytes, or -1 on failure.
  */
 ssize_t
-_mongoc_buffer_fill (mongoc_buffer_t *buffer,
-                     mongoc_stream_t *stream,
-                     size_t min_bytes,
-                     int64_t timeout_msec,
-                     bson_error_t *error)
+_mongoc_buffer_fill (
+   mongoc_buffer_t *buffer, mongoc_stream_t *stream, size_t min_bytes, int64_t timeout_msec, bson_error_t *error)
 {
    ssize_t ret;
    size_t avail_bytes;
@@ -251,7 +239,7 @@ _mongoc_buffer_fill (mongoc_buffer_t *buffer,
    BSON_ASSERT (buffer->datalen);
 
    if (min_bytes <= buffer->len) {
-      BSON_ASSERT (bson_in_range_unsigned (ssize_t, buffer->len));
+      BSON_ASSERT (mcommon_in_range_unsigned (ssize_t, buffer->len));
       RETURN ((ssize_t) buffer->len);
    }
 
@@ -261,29 +249,20 @@ _mongoc_buffer_fill (mongoc_buffer_t *buffer,
 
    avail_bytes = buffer->datalen - buffer->len;
 
-   if (BSON_UNLIKELY (!bson_in_range_signed (int32_t, timeout_msec))) {
+   if (BSON_UNLIKELY (!mcommon_in_range_signed (int32_t, timeout_msec))) {
       // CDRIVER-4589
       bson_set_error (error,
                       MONGOC_ERROR_STREAM,
                       MONGOC_ERROR_STREAM_SOCKET,
-                      "timeout_msec value %" PRId64
-                      " exceeds supported 32-bit range",
+                      "timeout_msec value %" PRId64 " exceeds supported 32-bit range",
                       timeout_msec);
       RETURN (false);
    }
 
-   ret = mongoc_stream_read (stream,
-                             &buffer->data[buffer->len],
-                             avail_bytes,
-                             min_bytes,
-                             (int32_t) timeout_msec);
+   ret = mongoc_stream_read (stream, &buffer->data[buffer->len], avail_bytes, min_bytes, (int32_t) timeout_msec);
 
    if (ret < 0) {
-      bson_set_error (error,
-                      MONGOC_ERROR_STREAM,
-                      MONGOC_ERROR_STREAM_SOCKET,
-                      "Failed to buffer %zu bytes",
-                      min_bytes);
+      bson_set_error (error, MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_SOCKET, "Failed to buffer %zu bytes", min_bytes);
       RETURN (-1);
    }
 
@@ -299,7 +278,7 @@ _mongoc_buffer_fill (mongoc_buffer_t *buffer,
       RETURN (-1);
    }
 
-   BSON_ASSERT (bson_in_range_unsigned (ssize_t, buffer->len));
+   BSON_ASSERT (mcommon_in_range_unsigned (ssize_t, buffer->len));
    RETURN ((ssize_t) buffer->len);
 }
 
@@ -340,11 +319,9 @@ _mongoc_buffer_try_append_from_stream (mongoc_buffer_t *buffer,
 
    BSON_ASSERT ((buffer->len + size) <= buffer->datalen);
 
-   if (BSON_UNLIKELY (!bson_in_range_signed (int32_t, timeout_msec))) {
+   if (BSON_UNLIKELY (!mcommon_in_range_signed (int32_t, timeout_msec))) {
       // CDRIVER-4589
-      MONGOC_ERROR ("timeout_msec value %" PRId64
-                    " exceeds supported 32-bit range",
-                    timeout_msec);
+      MONGOC_ERROR ("timeout_msec value %" PRId64 " exceeds supported 32-bit range", timeout_msec);
       RETURN (-1);
    }
 
