@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -17,6 +17,7 @@
 
 #include "mongoc.h"
 #include "mongoc-apm-private.h"
+#include "mongoc-array-private.h"
 #include "mongoc-counters-private.h"
 #include "mongoc-client-pool-private.h"
 #include "mongoc-client-pool.h"
@@ -32,6 +33,10 @@
 #include "mongoc-ssl-private.h"
 #endif
 
+#if defined(MONGOC_ENABLE_SSL_OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x10100000L
+#include "mongoc-openssl-private.h"
+#endif
+
 struct _mongoc_client_pool_t {
    bson_mutex_t mutex;
    mongoc_cond_t cond;
@@ -52,38 +57,42 @@ struct _mongoc_client_pool_t {
    bool error_api_set;
    mongoc_server_api_t *api;
    bool client_initialized;
+   // `last_known_serverids` is a sorted array of uint32_t.
+   mongoc_array_t last_known_serverids;
 };
 
 
 #ifdef MONGOC_ENABLE_SSL
 void
-mongoc_client_pool_set_ssl_opts (mongoc_client_pool_t *pool,
-                                 const mongoc_ssl_opt_t *opts)
+mongoc_client_pool_set_ssl_opts (mongoc_client_pool_t *pool, const mongoc_ssl_opt_t *opts)
 {
    BSON_ASSERT_PARAM (pool);
 
    bson_mutex_lock (&pool->mutex);
 
-   _mongoc_ssl_opts_cleanup (&pool->ssl_opts,
-                             false /* don't free internal opts. */);
+   _mongoc_ssl_opts_cleanup (&pool->ssl_opts, false /* don't free internal opts. */);
 
    pool->ssl_opts_set = false;
 
    if (opts) {
-      _mongoc_ssl_opts_copy_to (
-         opts, &pool->ssl_opts, false /* don't overwrite internal opts. */);
+      _mongoc_ssl_opts_copy_to (opts, &pool->ssl_opts, false /* don't overwrite internal opts. */);
       pool->ssl_opts_set = true;
+
+      /* Update the OpenSSL context associated with this client pool to match new ssl opts. */
+      /* All future clients popped from pool inherit this OpenSSL context. */
+#if defined(MONGOC_ENABLE_SSL_OPENSSL) && OPENSSL_VERSION_NUMBER >= 0x10100000L
+      SSL_CTX_free (pool->topology->scanner->openssl_ctx);
+      pool->topology->scanner->openssl_ctx = _mongoc_openssl_ctx_new (&pool->ssl_opts);
+#endif
    }
 
-   mongoc_topology_scanner_set_ssl_opts (pool->topology->scanner,
-                                         &pool->ssl_opts);
+   mongoc_topology_scanner_set_ssl_opts (pool->topology->scanner, &pool->ssl_opts);
 
    bson_mutex_unlock (&pool->mutex);
 }
 
 void
-_mongoc_client_pool_set_internal_tls_opts (
-   mongoc_client_pool_t *pool, _mongoc_internal_tls_opts_t *internal)
+_mongoc_client_pool_set_internal_tls_opts (mongoc_client_pool_t *pool, _mongoc_internal_tls_opts_t *internal)
 {
    BSON_ASSERT_PARAM (pool);
 
@@ -93,8 +102,7 @@ _mongoc_client_pool_set_internal_tls_opts (
       return;
    }
    pool->ssl_opts.internal = bson_malloc (sizeof (_mongoc_internal_tls_opts_t));
-   memcpy (
-      pool->ssl_opts.internal, internal, sizeof (_mongoc_internal_tls_opts_t));
+   memcpy (pool->ssl_opts.internal, internal, sizeof (_mongoc_internal_tls_opts_t));
    bson_mutex_unlock (&pool->mutex);
 }
 #endif
@@ -152,6 +160,7 @@ mongoc_client_pool_new_with_error (const mongoc_uri_t *uri, bson_error_t *error)
    }
 
    pool = (mongoc_client_pool_t *) bson_malloc0 (sizeof *pool);
+   _mongoc_array_init (&pool->last_known_serverids, sizeof (uint32_t));
    bson_mutex_init (&pool->mutex);
    mongoc_cond_init (&pool->cond);
    _mongoc_queue_init (&pool->queue);
@@ -165,10 +174,8 @@ mongoc_client_pool_new_with_error (const mongoc_uri_t *uri, bson_error_t *error)
    b = mongoc_uri_get_options (pool->uri);
 
    if (bson_iter_init_find_case (&iter, b, MONGOC_URI_MINPOOLSIZE)) {
-      MONGOC_WARNING (
-         MONGOC_URI_MINPOOLSIZE
-         " is deprecated; its behavior does not match its name, and its actual"
-         " behavior will likely hurt performance.");
+      MONGOC_WARNING (MONGOC_URI_MINPOOLSIZE " is deprecated; its behavior does not match its name, and its actual"
+                                             " behavior will likely hurt performance.");
 
       if (BSON_ITER_HOLDS_INT32 (&iter)) {
          pool->min_pool_size = BSON_MAX (0, bson_iter_int32 (&iter));
@@ -181,8 +188,7 @@ mongoc_client_pool_new_with_error (const mongoc_uri_t *uri, bson_error_t *error)
       }
    }
 
-   appname =
-      mongoc_uri_get_option_as_utf8 (pool->uri, MONGOC_URI_APPNAME, NULL);
+   appname = mongoc_uri_get_option_as_utf8 (pool->uri, MONGOC_URI_APPNAME, NULL);
    if (appname) {
       /* the appname should have already been validated */
       BSON_ASSERT (mongoc_client_pool_set_appname (pool, appname));
@@ -222,8 +228,7 @@ mongoc_client_pool_destroy (mongoc_client_pool_t *pool)
       mongoc_client_pool_push (pool, client);
    }
 
-   while (
-      (client = (mongoc_client_t *) _mongoc_queue_pop_head (&pool->queue))) {
+   while ((client = (mongoc_client_t *) _mongoc_queue_pop_head (&pool->queue))) {
       mongoc_client_destroy (client);
    }
 
@@ -239,6 +244,8 @@ mongoc_client_pool_destroy (mongoc_client_pool_t *pool)
    _mongoc_ssl_opts_cleanup (&pool->ssl_opts, true);
 #endif
 
+   _mongoc_array_destroy (&pool->last_known_serverids);
+
    bson_free (pool);
 
    mongoc_counter_client_pools_active_dec ();
@@ -271,15 +278,12 @@ _initialize_new_client (mongoc_client_pool_t *pool, mongoc_client_t *client)
 
    /* for tests */
    mongoc_client_set_stream_initiator (
-      client,
-      pool->topology->scanner->initiator,
-      pool->topology->scanner->initiator_context);
+      client, pool->topology->scanner->initiator, pool->topology->scanner->initiator_context);
 
    pool->client_initialized = true;
    client->is_pooled = true;
    client->error_api_version = pool->error_api_version;
-   _mongoc_client_set_apm_callbacks_private (
-      client, &pool->apm_callbacks, pool->apm_context);
+   _mongoc_client_set_apm_callbacks_private (client, &pool->apm_callbacks, pool->apm_context);
 
    client->api = mongoc_server_api_copy (pool->api);
 
@@ -303,11 +307,9 @@ mongoc_client_pool_pop (mongoc_client_pool_t *pool)
 
    BSON_ASSERT_PARAM (pool);
 
-   wait_queue_timeout_ms = mongoc_uri_get_option_as_int32 (
-      pool->uri, MONGOC_URI_WAITQUEUETIMEOUTMS, -1);
+   wait_queue_timeout_ms = mongoc_uri_get_option_as_int32 (pool->uri, MONGOC_URI_WAITQUEUETIMEOUTMS, -1);
    if (wait_queue_timeout_ms > 0) {
-      expire_at_ms =
-         (bson_get_monotonic_time () / 1000) + wait_queue_timeout_ms;
+      expire_at_ms = (bson_get_monotonic_time () / 1000) + wait_queue_timeout_ms;
    }
    bson_mutex_lock (&pool->mutex);
 
@@ -322,8 +324,7 @@ again:
          if (wait_queue_timeout_ms > 0) {
             now_ms = bson_get_monotonic_time () / 1000;
             if (now_ms < expire_at_ms) {
-               r = mongoc_cond_timedwait (
-                  &pool->cond, &pool->mutex, expire_at_ms - now_ms);
+               r = mongoc_cond_timedwait (&pool->cond, &pool->mutex, expire_at_ms - now_ms);
                if (mongo_cond_ret_is_timedout (r)) {
                   GOTO (done);
                }
@@ -373,6 +374,53 @@ mongoc_client_pool_try_pop (mongoc_client_pool_t *pool)
    RETURN (client);
 }
 
+typedef struct {
+   mongoc_array_t *known_server_ids;
+   mongoc_cluster_t *cluster;
+} prune_ctx;
+
+static int
+server_id_cmp (const void *a_, const void *b_)
+{
+   const uint32_t *const a = (const uint32_t *) a_;
+   const uint32_t *const b = (const uint32_t *) b_;
+
+   if (*a == *b) {
+      return 0;
+   }
+
+   return *a < *b ? -1 : 1;
+}
+
+// `maybe_prune` removes a `mongoc_cluster_node_t` if the node refers to a removed server.
+static bool
+maybe_prune (void *item, void *ctx_)
+{
+   mongoc_cluster_node_t *cn = (mongoc_cluster_node_t *) item;
+   prune_ctx *ctx = (prune_ctx *) ctx_;
+   // Get the server ID from the cluster node.
+   uint32_t server_id = cn->handshake_sd->id;
+
+   // Check if the cluster node's server ID references a removed server.
+   if (!bsearch (
+          &server_id, ctx->known_server_ids->data, ctx->known_server_ids->len, sizeof (uint32_t), server_id_cmp)) {
+      mongoc_cluster_disconnect_node (ctx->cluster, server_id);
+   }
+   return true;
+}
+
+// `prune_client` closes connections from `client` to servers not contained in `known_server_ids`.
+static void
+prune_client (mongoc_client_t *client, mongoc_array_t *known_server_ids)
+{
+   BSON_ASSERT_PARAM (client);
+   BSON_ASSERT_PARAM (known_server_ids);
+
+   mongoc_cluster_t *cluster = &client->cluster;
+   prune_ctx ctx = {.cluster = cluster, .known_server_ids = known_server_ids};
+   mongoc_set_for_each (cluster->nodes, maybe_prune, &ctx);
+}
+
 
 void
 mongoc_client_pool_push (mongoc_client_pool_t *pool, mongoc_client_t *client)
@@ -382,11 +430,55 @@ mongoc_client_pool_push (mongoc_client_pool_t *pool, mongoc_client_t *client)
    BSON_ASSERT_PARAM (pool);
    BSON_ASSERT_PARAM (client);
 
+   /* reset sockettimeoutms to the default in case it was changed with mongoc_client_set_sockettimeoutms() */
+   mongoc_cluster_reset_sockettimeoutms (&client->cluster);
+
    bson_mutex_lock (&pool->mutex);
+   // Check if `last_known_server_ids` needs update.
+   bool serverids_have_changed = false;
+   {
+      mongoc_array_t current_serverids;
+      _mongoc_array_init (&current_serverids, sizeof (uint32_t));
+
+      {
+         mc_shared_tpld td = mc_tpld_take_ref (pool->topology);
+         const mongoc_set_t *servers = mc_tpld_servers_const (td.ptr);
+         for (size_t i = 0; i < servers->items_len; i++) {
+            _mongoc_array_append_val (&current_serverids, servers->items[i].id);
+         }
+         mc_tpld_drop_ref (&td);
+      }
+
+      serverids_have_changed = (current_serverids.len != pool->last_known_serverids.len) ||
+                               memcmp (current_serverids.data,
+                                       pool->last_known_serverids.data,
+                                       current_serverids.len * current_serverids.element_size) != 0;
+
+      if (serverids_have_changed) {
+         _mongoc_array_destroy (&pool->last_known_serverids);
+         pool->last_known_serverids = current_serverids; // Ownership transfer.
+      } else {
+         _mongoc_array_destroy (&current_serverids);
+      }
+   }
+
+   // Check if pooled clients need to be pruned.
+   if (serverids_have_changed) {
+      // The set of last known server IDs has changed. Prune all clients in pool.
+      mongoc_queue_item_t *ptr = pool->queue.head;
+      while (ptr != NULL) {
+         prune_client ((mongoc_client_t *) ptr->data, &pool->last_known_serverids);
+         ptr = ptr->next;
+      }
+   }
+
+   // Always prune incoming client. The topology may have changed while client was checked out.
+   prune_client (client, &pool->last_known_serverids);
+
+   // Push client back into pool.
    _mongoc_queue_push_head (&pool->queue, client);
 
-   if (pool->min_pool_size &&
-       _mongoc_queue_get_length (&pool->queue) > pool->min_pool_size) {
+   if (pool->min_pool_size && _mongoc_queue_get_length (&pool->queue) > pool->min_pool_size) {
       mongoc_client_t *old_client;
       old_client = (mongoc_client_t *) _mongoc_queue_pop_tail (&pool->queue);
       if (old_client) {
@@ -403,14 +495,11 @@ mongoc_client_pool_push (mongoc_client_pool_t *pool, mongoc_client_t *client)
 
 /* for tests */
 void
-_mongoc_client_pool_set_stream_initiator (mongoc_client_pool_t *pool,
-                                          mongoc_stream_initiator_t si,
-                                          void *context)
+_mongoc_client_pool_set_stream_initiator (mongoc_client_pool_t *pool, mongoc_stream_initiator_t si, void *context)
 {
    BSON_ASSERT_PARAM (pool);
 
-   mongoc_topology_scanner_set_stream_initiator (
-      pool->topology->scanner, si, context);
+   mongoc_topology_scanner_set_stream_initiator (pool->topology->scanner, si, context);
 }
 
 /* for tests */
@@ -474,9 +563,8 @@ mongoc_client_pool_min_size (mongoc_client_pool_t *pool, uint32_t min_pool_size)
    ENTRY;
    BSON_ASSERT_PARAM (pool);
 
-   MONGOC_WARNING (
-      "mongoc_client_pool_min_size is deprecated; its behavior does not match"
-      " its name, and its actual behavior will likely hurt performance.");
+   MONGOC_WARNING ("mongoc_client_pool_min_size is deprecated; its behavior does not match"
+                   " its name, and its actual behavior will likely hurt performance.");
 
    bson_mutex_lock (&pool->mutex);
    pool->min_pool_size = min_pool_size;
@@ -486,35 +574,35 @@ mongoc_client_pool_min_size (mongoc_client_pool_t *pool, uint32_t min_pool_size)
 }
 
 bool
-mongoc_client_pool_set_apm_callbacks (mongoc_client_pool_t *pool,
-                                      mongoc_apm_callbacks_t *callbacks,
-                                      void *context)
+mongoc_client_pool_set_apm_callbacks (mongoc_client_pool_t *pool, mongoc_apm_callbacks_t *callbacks, void *context)
 {
    BSON_ASSERT_PARAM (pool);
 
    mongoc_topology_t *const topology = BSON_ASSERT_PTR_INLINE (pool)->topology;
-   mc_tpld_modification tdmod;
+   mc_tpld_modification tdmod = mc_tpld_modify_begin (topology);
 
+   // Prevent setting callbacks more than once
    if (pool->apm_callbacks_set) {
+      mc_tpld_modify_drop (tdmod);
       MONGOC_ERROR ("Can only set callbacks once");
       return false;
    }
 
-   tdmod = mc_tpld_modify_begin (topology);
-
+   // Update callbacks on the pool
    if (callbacks) {
-      memcpy (&tdmod.new_td->apm_callbacks,
-              callbacks,
-              sizeof (mongoc_apm_callbacks_t));
-      memcpy (&pool->apm_callbacks, callbacks, sizeof (mongoc_apm_callbacks_t));
+      pool->apm_callbacks = *callbacks;
+   } else {
+      pool->apm_callbacks = (mongoc_apm_callbacks_t){0};
    }
-
-   mongoc_topology_set_apm_callbacks (
-      topology, tdmod.new_td, callbacks, context);
-   tdmod.new_td->apm_context = context;
    pool->apm_context = context;
+
+   // Update callbacks on the topology
+   mongoc_topology_set_apm_callbacks (topology, tdmod.new_td, callbacks, context);
+
+   // Signal that we have already set the callbacks
    pool->apm_callbacks_set = true;
 
+   // Save our updated topology
    mc_tpld_modify_commit (tdmod);
 
    return true;
@@ -523,8 +611,7 @@ mongoc_client_pool_set_apm_callbacks (mongoc_client_pool_t *pool,
 bool
 mongoc_client_pool_set_error_api (mongoc_client_pool_t *pool, int32_t version)
 {
-   if (version != MONGOC_ERROR_API_VERSION_LEGACY &&
-       version != MONGOC_ERROR_API_VERSION_2) {
+   if (version != MONGOC_ERROR_API_VERSION_LEGACY && version != MONGOC_ERROR_API_VERSION_2) {
       MONGOC_ERROR ("Unsupported Error API Version: %" PRId32, version);
       return false;
    }
@@ -563,23 +650,18 @@ mongoc_client_pool_enable_auto_encryption (mongoc_client_pool_t *pool,
 {
    BSON_ASSERT_PARAM (pool);
 
-   return _mongoc_cse_client_pool_enable_auto_encryption (
-      pool->topology, opts, error);
+   return _mongoc_cse_client_pool_enable_auto_encryption (pool->topology, opts, error);
 }
 
 bool
-mongoc_client_pool_set_server_api (mongoc_client_pool_t *pool,
-                                   const mongoc_server_api_t *api,
-                                   bson_error_t *error)
+mongoc_client_pool_set_server_api (mongoc_client_pool_t *pool, const mongoc_server_api_t *api, bson_error_t *error)
 {
    BSON_ASSERT_PARAM (pool);
    BSON_ASSERT_PARAM (api);
 
    if (pool->api) {
-      bson_set_error (error,
-                      MONGOC_ERROR_POOL,
-                      MONGOC_ERROR_POOL_API_ALREADY_SET,
-                      "Cannot set server api more than once per pool");
+      bson_set_error (
+         error, MONGOC_ERROR_POOL, MONGOC_ERROR_POOL_API_ALREADY_SET, "Cannot set server api more than once per pool");
       return false;
    }
 
