@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -67,13 +67,17 @@ typedef struct _mongoc_cluster_t {
 
 
 void
-mongoc_cluster_init (mongoc_cluster_t *cluster,
-                     const mongoc_uri_t *uri,
-                     void *client);
+mongoc_cluster_init (mongoc_cluster_t *cluster, const mongoc_uri_t *uri, void *client);
 
 void
 mongoc_cluster_destroy (mongoc_cluster_t *cluster);
 
+void
+mongoc_cluster_set_sockettimeoutms (mongoc_cluster_t *cluster, int32_t sockettimeoutms);
+
+void
+mongoc_cluster_reset_sockettimeoutms (mongoc_cluster_t *cluster);
+
 void
 mongoc_cluster_disconnect_node (mongoc_cluster_t *cluster, uint32_t id);
 
@@ -84,20 +88,16 @@ int32_t
 mongoc_cluster_get_max_msg_size (mongoc_cluster_t *cluster);
 
 size_t
-_mongoc_cluster_buffer_iovec (mongoc_iovec_t *iov,
-                              size_t iovcnt,
-                              int skip,
-                              char *buffer);
+_mongoc_cluster_buffer_iovec (mongoc_iovec_t *iov, size_t iovcnt, int skip, char *buffer);
 
 bool
 mongoc_cluster_check_interval (mongoc_cluster_t *cluster, uint32_t server_id);
 
 bool
-mongoc_cluster_legacy_rpc_sendv_to_server (
-   mongoc_cluster_t *cluster,
-   mcd_rpc_message *rpc,
-   mongoc_server_stream_t *server_stream,
-   bson_error_t *error);
+mongoc_cluster_legacy_rpc_sendv_to_server (mongoc_cluster_t *cluster,
+                                           mcd_rpc_message *rpc,
+                                           mongoc_server_stream_t *server_stream,
+                                           bson_error_t *error);
 
 bool
 mongoc_cluster_try_recv (mongoc_cluster_t *cluster,
@@ -157,12 +157,11 @@ mongoc_cluster_stream_for_writes (mongoc_cluster_t *cluster,
  * @note May add nodes and/or update the cluster's topology.
  */
 mongoc_server_stream_t *
-mongoc_cluster_stream_for_aggr_with_write (
-   mongoc_cluster_t *cluster,
-   const mongoc_read_prefs_t *read_prefs,
-   mongoc_client_session_t *cs,
-   bson_t *reply,
-   bson_error_t *error);
+mongoc_cluster_stream_for_aggr_with_write (mongoc_cluster_t *cluster,
+                                           const mongoc_read_prefs_t *read_prefs,
+                                           mongoc_client_session_t *cs,
+                                           bson_t *reply,
+                                           bson_error_t *error);
 
 /**
  * @brief Obtain a server stream associated with the cluster node associated
@@ -188,14 +187,22 @@ mongoc_cluster_stream_for_server (mongoc_cluster_t *cluster,
                                   bson_error_t *error);
 
 bool
-mongoc_cluster_stream_valid (mongoc_cluster_t *cluster,
-                             mongoc_server_stream_t *server_stream);
+mongoc_cluster_stream_valid (mongoc_cluster_t *cluster, mongoc_server_stream_t *server_stream);
 
 bool
-mongoc_cluster_run_command_monitored (mongoc_cluster_t *cluster,
-                                      mongoc_cmd_t *cmd,
-                                      bson_t *reply,
-                                      bson_error_t *error);
+mongoc_cluster_run_command_monitored (mongoc_cluster_t *cluster, mongoc_cmd_t *cmd, bson_t *reply, bson_error_t *error);
+
+// `mongoc_cluster_run_retryable_write` executes a write command and may apply retryable writes behavior.
+// `cmd->server_stream` is set to `*retry_server_stream` on retry. Otherwise, it is unmodified.
+// `*retry_server_stream` is set to a new stream on retry. The caller must call `mongoc_server_stream_cleanup`.
+// `*reply` must be uninitialized and is always initialized upon return. The caller must call `bson_destroy`.
+bool
+mongoc_cluster_run_retryable_write (mongoc_cluster_t *cluster,
+                                    mongoc_cmd_t *cmd,
+                                    bool is_retryable_write,
+                                    mongoc_server_stream_t **retry_server_stream,
+                                    bson_t *reply,
+                                    bson_error_t *error);
 
 bool
 mongoc_cluster_run_command_parts (mongoc_cluster_t *cluster,
@@ -206,21 +213,15 @@ mongoc_cluster_run_command_parts (mongoc_cluster_t *cluster,
 
 bool
 mongoc_cluster_run_command_private (mongoc_cluster_t *cluster,
-                                    mongoc_cmd_t *cmd,
+                                    const mongoc_cmd_t *cmd,
                                     bson_t *reply,
                                     bson_error_t *error);
 
 void
-_mongoc_cluster_build_sasl_start (bson_t *cmd,
-                                  const char *mechanism,
-                                  const char *buf,
-                                  uint32_t buflen);
+_mongoc_cluster_build_sasl_start (bson_t *cmd, const char *mechanism, const char *buf, uint32_t buflen);
 
 void
-_mongoc_cluster_build_sasl_continue (bson_t *cmd,
-                                     int conv_id,
-                                     const char *buf,
-                                     uint32_t buflen);
+_mongoc_cluster_build_sasl_continue (bson_t *cmd, int conv_id, const char *buf, uint32_t buflen);
 
 int
 _mongoc_cluster_get_conversation_id (const bson_t *reply);
@@ -268,14 +269,10 @@ mcd_rpc_message_compress (mcd_rpc_message *rpc,
                           bson_error_t *error);
 
 bool
-mcd_rpc_message_decompress (mcd_rpc_message *rpc,
-                            void **data,
-                            size_t *data_len);
+mcd_rpc_message_decompress (mcd_rpc_message *rpc, void **data, size_t *data_len);
 
 bool
-mcd_rpc_message_decompress_if_necessary (mcd_rpc_message *rpc,
-                                         void **data,
-                                         size_t *data_len);
+mcd_rpc_message_decompress_if_necessary (mcd_rpc_message *rpc, void **data, size_t *data_len);
 
 BSON_END_DECLS
 
