@@ -1,5 +1,5 @@
 /*
- * Copyright 2018-present MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -49,13 +49,9 @@ _getmore_type (mongoc_cursor_t *cursor)
    wire_version = server_stream->sd->max_wire_version;
    mongoc_server_stream_cleanup (server_stream);
 
-   if (
-      /* Server version 5.1 and newer do not support OP_GETMORE. */
-      wire_version > WIRE_VERSION_5_0 ||
-      /* Fallback to legacy OP_GETMORE wire protocol messages if exhaust cursor
-         requested with server version 3.6 or newer . */
-      (wire_version >= WIRE_VERSION_FIND_CMD &&
-       !_mongoc_cursor_get_opt_bool (cursor, MONGOC_CURSOR_EXHAUST))) {
+   // CDRIVER-4722: always GETMORE_CMD once WIRE_VERSION_MIN >=
+   // WIRE_VERSION_4_2.
+   if (_mongoc_cursor_use_op_msg (cursor, wire_version)) {
       data->getmore_type = GETMORE_CMD;
    } else {
       data->getmore_type = OP_GETMORE;
@@ -74,13 +70,11 @@ _prime (mongoc_cursor_t *cursor)
 
    cursor->operation_id = ++cursor->client->cluster.operation_id;
    /* commands like agg have a cursor field, so copy opts without "batchSize" */
-   bson_copy_to_excluding_noinit (
-      &cursor->opts, &copied_opts, "batchSize", "tailable", NULL);
+   bson_copy_to_excluding_noinit (&cursor->opts, &copied_opts, "batchSize", "tailable", NULL);
 
    /* server replies to aggregate/listIndexes/listCollections with:
     * {cursor: {id: N, firstBatch: []}} */
-   _mongoc_cursor_response_refresh (
-      cursor, &data->cmd, &copied_opts, &data->response);
+   _mongoc_cursor_response_refresh (cursor, &data->cmd, &copied_opts, &data->response);
    data->reading_from = CMD_RESPONSE;
    bson_destroy (&copied_opts);
    return IN_BATCH;
@@ -122,8 +116,7 @@ _get_next_batch (mongoc_cursor_t *cursor)
    switch (getmore_type) {
    case GETMORE_CMD:
       _mongoc_cursor_prepare_getmore_command (cursor, &getmore_cmd);
-      _mongoc_cursor_response_refresh (
-         cursor, &getmore_cmd, NULL /* opts */, &data->response);
+      _mongoc_cursor_response_refresh (cursor, &getmore_cmd, NULL /* opts */, &data->response);
       bson_destroy (&getmore_cmd);
       data->reading_from = CMD_RESPONSE;
       return IN_BATCH;
@@ -170,11 +163,12 @@ _mongoc_cursor_cmd_new (mongoc_client_t *client,
                         const mongoc_read_prefs_t *default_prefs,
                         const mongoc_read_concern_t *read_concern)
 {
+   BSON_ASSERT_PARAM (client);
+
    mongoc_cursor_t *cursor;
    data_cmd_t *data = BSON_ALIGNED_ALLOC0 (data_cmd_t);
 
-   cursor = _mongoc_cursor_new_with_opts (
-      client, db_and_coll, opts, user_prefs, default_prefs, read_concern);
+   cursor = _mongoc_cursor_new_with_opts (client, db_and_coll, opts, user_prefs, default_prefs, read_concern);
    _mongoc_cursor_response_legacy_init (&data->response_legacy);
    _mongoc_cursor_check_and_copy_to (cursor, "command", cmd, &data->cmd);
    bson_init (&data->response.reply);
@@ -189,13 +183,11 @@ _mongoc_cursor_cmd_new (mongoc_client_t *client,
 
 
 mongoc_cursor_t *
-_mongoc_cursor_cmd_new_from_reply (mongoc_client_t *client,
-                                   const bson_t *cmd,
-                                   const bson_t *opts,
-                                   bson_t *reply)
+_mongoc_cursor_cmd_new_from_reply (mongoc_client_t *client, const bson_t *cmd, const bson_t *opts, bson_t *reply)
 {
-   mongoc_cursor_t *cursor =
-      _mongoc_cursor_cmd_new (client, NULL, cmd, opts, NULL, NULL, NULL);
+   BSON_ASSERT_PARAM (client);
+
+   mongoc_cursor_t *cursor = _mongoc_cursor_cmd_new (client, NULL, cmd, opts, NULL, NULL, NULL);
    data_cmd_t *data = (data_cmd_t *) cursor->impl.data;
 
    data->reading_from = CMD_RESPONSE;
@@ -208,10 +200,28 @@ _mongoc_cursor_cmd_new_from_reply (mongoc_client_t *client,
    }
 
    if (!_mongoc_cursor_start_reading_response (cursor, &data->response)) {
+      bson_set_error (
+         &cursor->error, MONGOC_ERROR_CURSOR, MONGOC_ERROR_CURSOR_INVALID_CURSOR, "Couldn't parse cursor document");
+   }
+
+   if (0 != cursor->cursor_id && 0 == cursor->server_id) {
+      // A non-zero cursor_id means the cursor is still open on the server.
+      // Expect the "serverId" option to have been passed. The "serverId" option
+      // identifies the server with the cursor.
+      // The server with the cursor is required to send a "getMore" or
+      // "killCursors" command.
       bson_set_error (&cursor->error,
                       MONGOC_ERROR_CURSOR,
                       MONGOC_ERROR_CURSOR_INVALID_CURSOR,
-                      "Couldn't parse cursor document");
+                      "Expected `serverId` option to identify server with open cursor "
+                      "(cursor ID is %" PRId64 "). "
+                      "Consider using `mongoc_client_select_server` and using the "
+                      "resulting server ID to create the cursor.",
+                      cursor->cursor_id);
+      // Reset cursor_id to 0 to avoid an assertion error in
+      // `mongoc_cursor_destroy` when attempting to send "killCursors".
+      cursor->cursor_id = 0;
    }
+
    return cursor;
 }
