@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,10 +18,10 @@
 #undef MONGOC_LOG_DOMAIN
 #define MONGOC_LOG_DOMAIN "gridfs_file_page"
 
-#include "mongoc/mongoc-gridfs-file-page.h"
-#include "mongoc/mongoc-gridfs-file-page-private.h"
+#include "mongoc-gridfs-file-page.h"
+#include "mongoc-gridfs-file-page-private.h"
 
-#include "mongoc/mongoc-trace-private.h"
+#include "mongoc-trace-private.h"
 
 
 /** create a new page from a buffer
@@ -29,9 +29,7 @@
  * The buffer should stick around for the life of the page
  */
 mongoc_gridfs_file_page_t *
-_mongoc_gridfs_file_page_new (const uint8_t *data,
-                              uint32_t len,
-                              uint32_t chunk_size)
+_mongoc_gridfs_file_page_new (const uint8_t *data, uint32_t len, uint32_t chunk_size)
 {
    mongoc_gridfs_file_page_t *page;
 
@@ -64,9 +62,7 @@ _mongoc_gridfs_file_page_seek (mongoc_gridfs_file_page_t *page, uint32_t offset)
 
 
 int32_t
-_mongoc_gridfs_file_page_read (mongoc_gridfs_file_page_t *page,
-                               void *dst,
-                               uint32_t len)
+_mongoc_gridfs_file_page_read (mongoc_gridfs_file_page_t *page, void *dst, uint32_t len)
 {
    int bytes_read;
    const uint8_t *src;
@@ -93,7 +89,7 @@ _mongoc_gridfs_file_page_read (mongoc_gridfs_file_page_t *page,
  *
  * Write to a page.
  *
-* Writes are copy-on-write with regards to the buffer that was passed to the
+ * Writes are copy-on-write with regards to the buffer that was passed to the
  * mongoc_gridfs_file_page_t during construction. In other words, the first
  * write allocates a large enough buffer for file->chunk_size, which becomes
  * authoritative from then on.
@@ -101,9 +97,7 @@ _mongoc_gridfs_file_page_read (mongoc_gridfs_file_page_t *page,
  * A write of zero bytes will trigger the copy-on-write mechanism.
  */
 int32_t
-_mongoc_gridfs_file_page_write (mongoc_gridfs_file_page_t *page,
-                                const void *src,
-                                uint32_t len)
+_mongoc_gridfs_file_page_write (mongoc_gridfs_file_page_t *page, const void *src, uint32_t len)
 {
    int bytes_written;
 
@@ -116,8 +110,7 @@ _mongoc_gridfs_file_page_write (mongoc_gridfs_file_page_t *page,
 
    if (!page->buf) {
       page->buf = (uint8_t *) bson_malloc (page->chunk_size);
-      memcpy (
-         page->buf, page->read_buf, BSON_MIN (page->chunk_size, page->len));
+      memcpy (page->buf, page->read_buf, BSON_MIN (page->chunk_size, page->len));
    }
 
    /* Copy bytes and adjust the page position */
@@ -158,8 +151,7 @@ _mongoc_gridfs_file_page_memset0 (mongoc_gridfs_file_page_t *page, uint32_t len)
 
    if (!page->buf) {
       page->buf = (uint8_t *) bson_malloc0 (page->chunk_size);
-      memcpy (
-         page->buf, page->read_buf, BSON_MIN (page->chunk_size, page->len));
+      memcpy (page->buf, page->read_buf, BSON_MIN (page->chunk_size, page->len));
    }
 
    /* Set bytes and adjust the page position */
