@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -50,23 +50,22 @@ static bool
 _mongoc_gridfs_ensure_index (mongoc_gridfs_t *gridfs, bson_error_t *error)
 {
    bson_t keys;
-   mongoc_index_opt_t opt;
+   bson_t opts;
    bool r;
 
    ENTRY;
 
+   bson_init (&opts);
+   BSON_APPEND_BOOL (&opts, "unique", true);
+
    bson_init (&keys);
 
-   bson_append_int32 (&keys, "files_id", -1, 1);
-   bson_append_int32 (&keys, "n", -1, 1);
+   BSON_APPEND_INT32 (&keys, "files_id", 1);
+   BSON_APPEND_INT32 (&keys, "n", 1);
 
-   mongoc_index_opt_init (&opt);
-   opt.unique = 1;
-
-   BEGIN_IGNORE_DEPRECATIONS
-   r = mongoc_collection_create_index (gridfs->chunks, &keys, &opt, error);
-   END_IGNORE_DEPRECATIONS
+   r = _mongoc_collection_create_index_if_not_exists (gridfs->chunks, &keys, &opts, error);
 
+   bson_destroy (&opts);
    bson_destroy (&keys);
 
    if (!r) {
@@ -75,13 +74,11 @@ _mongoc_gridfs_ensure_index (mongoc_gridfs_t *gridfs, bson_error_t *error)
 
    bson_init (&keys);
 
-   bson_append_int32 (&keys, "filename", -1, 1);
-   bson_append_int32 (&keys, "uploadDate", -1, 1);
-   opt.unique = 0;
+   BSON_APPEND_INT32 (&keys, "filename", 1);
+   BSON_APPEND_INT32 (&keys, "uploadDate", 1);
+
+   r = _mongoc_collection_create_index_if_not_exists (gridfs->files, &keys, NULL, error);
 
-   BEGIN_IGNORE_DEPRECATIONS
-   r = mongoc_collection_create_index (gridfs->files, &keys, &opt, error);
-   END_IGNORE_DEPRECATIONS
    bson_destroy (&keys);
 
    if (!r) {
@@ -93,10 +90,7 @@ _mongoc_gridfs_ensure_index (mongoc_gridfs_t *gridfs, bson_error_t *error)
 
 
 mongoc_gridfs_t *
-_mongoc_gridfs_new (mongoc_client_t *client,
-                    const char *db,
-                    const char *prefix,
-                    bson_error_t *error)
+_mongoc_gridfs_new (mongoc_client_t *client, const char *db, const char *prefix, bson_error_t *error)
 {
    mongoc_gridfs_t *gridfs;
    char buf[128];
@@ -105,7 +99,7 @@ _mongoc_gridfs_new (mongoc_client_t *client,
 
    ENTRY;
 
-   BSON_ASSERT (client);
+   BSON_ASSERT_PARAM (client);
    BSON_ASSERT (db);
 
    if (!prefix) {
@@ -122,10 +116,13 @@ _mongoc_gridfs_new (mongoc_client_t *client,
 
    gridfs->client = client;
 
-   bson_snprintf (buf, sizeof (buf), "%s.chunks", prefix);
+   // Expect no truncation from above, checking no error occurred.
+   int req = bson_snprintf (buf, sizeof (buf), "%s.chunks", prefix);
+   BSON_ASSERT (req > 0);
    gridfs->chunks = mongoc_client_get_collection (client, db, buf);
 
-   bson_snprintf (buf, sizeof (buf), "%s.files", prefix);
+   req = bson_snprintf (buf, sizeof (buf), "%s.files", prefix);
+   BSON_ASSERT (req > 0);
    gridfs->files = mongoc_client_get_collection (client, db, buf);
 
    r = _mongoc_gridfs_ensure_index (gridfs, error);
@@ -188,9 +185,7 @@ mongoc_gridfs_find (mongoc_gridfs_t *gridfs, const bson_t *query)
 
 /** find a single gridfs file */
 mongoc_gridfs_file_t *
-mongoc_gridfs_find_one (mongoc_gridfs_t *gridfs,
-                        const bson_t *query,
-                        bson_error_t *error)
+mongoc_gridfs_find_one (mongoc_gridfs_t *gridfs, const bson_t *query, bson_error_t *error)
 {
    mongoc_gridfs_file_list_t *list;
    mongoc_gridfs_file_t *file;
@@ -213,9 +208,7 @@ mongoc_gridfs_find_one (mongoc_gridfs_t *gridfs,
 
 /** find all matching gridfs files */
 mongoc_gridfs_file_list_t *
-mongoc_gridfs_find_with_opts (mongoc_gridfs_t *gridfs,
-                              const bson_t *filter,
-                              const bson_t *opts)
+mongoc_gridfs_find_with_opts (mongoc_gridfs_t *gridfs, const bson_t *filter, const bson_t *opts)
 {
    return _mongoc_gridfs_file_list_new_with_opts (gridfs, filter, opts);
 }
@@ -259,9 +252,7 @@ mongoc_gridfs_find_one_with_opts (mongoc_gridfs_t *gridfs,
 
 /** find a single gridfs file by filename */
 mongoc_gridfs_file_t *
-mongoc_gridfs_find_one_by_filename (mongoc_gridfs_t *gridfs,
-                                    const char *filename,
-                                    bson_error_t *error)
+mongoc_gridfs_find_one_by_filename (mongoc_gridfs_t *gridfs, const char *filename, bson_error_t *error)
 {
    mongoc_gridfs_file_t *file;
 
@@ -284,9 +275,7 @@ mongoc_gridfs_find_one_by_filename (mongoc_gridfs_t *gridfs,
  * The stream is fully consumed in creating the file
  */
 mongoc_gridfs_file_t *
-mongoc_gridfs_create_file_from_stream (mongoc_gridfs_t *gridfs,
-                                       mongoc_stream_t *stream,
-                                       mongoc_gridfs_file_opt_t *opt)
+mongoc_gridfs_create_file_from_stream (mongoc_gridfs_t *gridfs, mongoc_stream_t *stream, mongoc_gridfs_file_opt_t *opt)
 {
    mongoc_gridfs_file_t *file;
    ssize_t r;
@@ -306,15 +295,19 @@ mongoc_gridfs_create_file_from_stream (mongoc_gridfs_t *gridfs,
    timeout = gridfs->client->cluster.sockettimeoutms;
 
    for (;;) {
-      r = mongoc_stream_read (
-         stream, iov.iov_base, MONGOC_GRIDFS_STREAM_CHUNK, 0, timeout);
+      r = mongoc_stream_read (stream, iov.iov_base, MONGOC_GRIDFS_STREAM_CHUNK, 0, timeout);
 
       if (r > 0) {
          iov.iov_len = r;
-         mongoc_gridfs_file_writev (file, &iov, 1, timeout);
+         if (mongoc_gridfs_file_writev (file, &iov, 1, timeout) < 0) {
+            MONGOC_ERROR ("%s", file->error.message);
+            mongoc_gridfs_file_destroy (file);
+            RETURN (NULL);
+         }
       } else if (r == 0) {
          break;
       } else {
+         MONGOC_ERROR ("Error reading from GridFS file source stream");
          mongoc_gridfs_file_destroy (file);
          RETURN (NULL);
       }
@@ -323,6 +316,8 @@ mongoc_gridfs_create_file_from_stream (mongoc_gridfs_t *gridfs,
    mongoc_stream_failed (stream);
 
    if (-1 == mongoc_gridfs_file_seek (file, 0, SEEK_SET)) {
+      MONGOC_ERROR ("%s", file->error.message);
+      mongoc_gridfs_file_destroy (file);
       RETURN (NULL);
    }
 
@@ -332,8 +327,7 @@ mongoc_gridfs_create_file_from_stream (mongoc_gridfs_t *gridfs,
 
 /** create an empty gridfs file */
 mongoc_gridfs_file_t *
-mongoc_gridfs_create_file (mongoc_gridfs_t *gridfs,
-                           mongoc_gridfs_file_opt_t *opt)
+mongoc_gridfs_create_file (mongoc_gridfs_t *gridfs, mongoc_gridfs_file_opt_t *opt)
 {
    mongoc_gridfs_file_t *file;
 
@@ -365,9 +359,7 @@ mongoc_gridfs_get_chunks (mongoc_gridfs_t *gridfs)
 
 
 bool
-mongoc_gridfs_remove_by_filename (mongoc_gridfs_t *gridfs,
-                                  const char *filename,
-                                  bson_error_t *error)
+mongoc_gridfs_remove_by_filename (mongoc_gridfs_t *gridfs, const char *filename, bson_error_t *error)
 {
    mongoc_bulk_operation_t *bulk_files = NULL;
    mongoc_bulk_operation_t *bulk_chunks = NULL;
@@ -393,10 +385,8 @@ mongoc_gridfs_remove_by_filename (mongoc_gridfs_t *gridfs,
    BSON_ASSERT (gridfs);
 
    if (!filename) {
-      bson_set_error (error,
-                      MONGOC_ERROR_GRIDFS,
-                      MONGOC_ERROR_GRIDFS_INVALID_FILENAME,
-                      "A non-NULL filename must be specified.");
+      bson_set_error (
+         error, MONGOC_ERROR_GRIDFS, MONGOC_ERROR_GRIDFS_INVALID_FILENAME, "A non-NULL filename must be specified.");
       return false;
    }
 
@@ -434,10 +424,8 @@ mongoc_gridfs_remove_by_filename (mongoc_gridfs_t *gridfs,
    }
 
    bson_append_bool (&opts, "ordered", 7, false);
-   bulk_files =
-      mongoc_collection_create_bulk_operation_with_opts (gridfs->files, &opts);
-   bulk_chunks =
-      mongoc_collection_create_bulk_operation_with_opts (gridfs->chunks, &opts);
+   bulk_files = mongoc_collection_create_bulk_operation_with_opts (gridfs->files, &opts);
+   bulk_chunks = mongoc_collection_create_bulk_operation_with_opts (gridfs->chunks, &opts);
 
    bson_destroy (&opts);
 
@@ -448,8 +436,7 @@ mongoc_gridfs_remove_by_filename (mongoc_gridfs_t *gridfs,
    mongoc_bulk_operation_remove (bulk_chunks, chunks_q);
 
    files_ret = mongoc_bulk_operation_execute (bulk_files, NULL, &files_error);
-   chunks_ret =
-      mongoc_bulk_operation_execute (bulk_chunks, NULL, &chunks_error);
+   chunks_ret = mongoc_bulk_operation_execute (bulk_chunks, NULL, &chunks_error);
 
    if (error) {
       if (!files_ret) {
