@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,19 +14,19 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-config.h"
+#include "mongoc-config.h"
 
 #ifdef MONGOC_ENABLE_SSL_LIBRESSL
 
 #include <bson/bson.h>
 
-#include "mongoc/mongoc-log.h"
-#include "mongoc/mongoc-trace-private.h"
-#include "mongoc/mongoc-ssl.h"
-#include "mongoc/mongoc-stream-tls.h"
-#include "mongoc/mongoc-stream-tls-private.h"
-#include "mongoc/mongoc-libressl-private.h"
-#include "mongoc/mongoc-stream-tls-libressl-private.h"
+#include "mongoc-log.h"
+#include "mongoc-trace-private.h"
+#include "mongoc-ssl.h"
+#include "mongoc-stream-tls.h"
+#include "mongoc-stream-tls-private.h"
+#include "mongoc-libressl-private.h"
+#include "mongoc-stream-tls-libressl-private.h"
 
 #include <tls.h>
 
@@ -35,8 +35,7 @@
 
 
 bool
-mongoc_libressl_setup_certificate (mongoc_stream_tls_libressl_t *libressl,
-                                   mongoc_ssl_opt_t *opt)
+mongoc_libressl_setup_certificate (mongoc_stream_tls_libressl_t *libressl, mongoc_ssl_opt_t *opt)
 {
    uint8_t *file;
    size_t file_len;
@@ -51,8 +50,7 @@ mongoc_libressl_setup_certificate (mongoc_stream_tls_libressl_t *libressl,
       return false;
    }
 
-   if (tls_config_set_keypair_mem (
-          libressl->config, file, file_len, file, file_len) == -1) {
+   if (tls_config_set_keypair_mem (libressl->config, file, file_len, file, file_len) == -1) {
       MONGOC_ERROR ("%s", tls_config_error (libressl->config));
       return false;
    }
@@ -61,8 +59,7 @@ mongoc_libressl_setup_certificate (mongoc_stream_tls_libressl_t *libressl,
 }
 
 bool
-mongoc_libressl_setup_ca (mongoc_stream_tls_libressl_t *libressl,
-                          mongoc_ssl_opt_t *opt)
+mongoc_libressl_setup_ca (mongoc_stream_tls_libressl_t *libressl, mongoc_ssl_opt_t *opt)
 {
    if (opt->ca_file) {
       tls_config_set_ca_file (libressl->config, opt->ca_file);
