@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -24,10 +24,7 @@
 
 
 static mongoc_matcher_op_t *
-_mongoc_matcher_parse_logical (mongoc_matcher_opcode_t  opcode,
-                               bson_iter_t             *iter,
-                               bool                     is_root,
-                               bson_error_t            *error);
+_mongoc_matcher_parse_logical (mongoc_matcher_opcode_t opcode, bson_iter_t *iter, bool is_root, bson_error_t *error);
 
 
 /*
@@ -39,7 +36,7 @@ _mongoc_matcher_parse_logical (mongoc_matcher_opcode_t  opcode,
  *
  *       See the following link for more information.
  *
- *          http://docs.mongodb.org/manual/reference/operator/query/
+ *          https://www.mongodb.com/docs/manual/reference/operator/query/
  *
  * Returns:
  *       A newly allocated mongoc_matcher_op_t if successful; otherwise
@@ -52,69 +49,52 @@ _mongoc_matcher_parse_logical (mongoc_matcher_opcode_t  opcode,
  */
 
 static mongoc_matcher_op_t *
-_mongoc_matcher_parse_compare (bson_iter_t  *iter,  /* IN */
-                               const char   *path,  /* IN */
+_mongoc_matcher_parse_compare (bson_iter_t *iter,   /* IN */
+                               const char *path,    /* IN */
                                bson_error_t *error) /* OUT */
 {
-   const char * key;
-   mongoc_matcher_op_t * op = NULL, * op_child;
+   const char *key;
+   mongoc_matcher_op_t *op = NULL, *op_child;
    bson_iter_t child;
 
    BSON_ASSERT (iter);
    BSON_ASSERT (path);
 
    if (bson_iter_type (iter) == BSON_TYPE_DOCUMENT) {
-      if (!bson_iter_recurse (iter, &child) ||
-          !bson_iter_next (&child)) {
-         bson_set_error (error,
-                         MONGOC_ERROR_MATCHER,
-                         MONGOC_ERROR_MATCHER_INVALID,
-                         "Document contains no operations.");
+      if (!bson_iter_recurse (iter, &child) || !bson_iter_next (&child)) {
+         bson_set_error (error, MONGOC_ERROR_MATCHER, MONGOC_ERROR_MATCHER_INVALID, "Document contains no operations.");
          return NULL;
       }
 
       key = bson_iter_key (&child);
 
       if (key[0] != '$') {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_EQ, path,
-                                              iter);
-      } else if (strcmp(key, "$not") == 0) {
-         if (!(op_child = _mongoc_matcher_parse_compare (&child, path,
-                                                         error))) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_EQ, path, iter);
+      } else if (strcmp (key, "$not") == 0) {
+         if (!(op_child = _mongoc_matcher_parse_compare (&child, path, error))) {
             return NULL;
          }
          op = _mongoc_matcher_op_not_new (path, op_child);
-      } else if (strcmp(key, "$gt") == 0) {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_GT, path,
-                                              &child);
-      } else if (strcmp(key, "$gte") == 0) {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_GTE, path,
-                                              &child);
-      } else if (strcmp(key, "$in") == 0) {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_IN, path,
-                                              &child);
-      } else if (strcmp(key, "$lt") == 0) {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_LT, path,
-                                              &child);
-      } else if (strcmp(key, "$lte") == 0) {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_LTE, path,
-                                              &child);
-      } else if (strcmp(key, "$ne") == 0) {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_NE, path,
-                                              &child);
-      } else if (strcmp(key, "$nin") == 0) {
-         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_NIN, path,
-                                              &child);
-      } else if (strcmp(key, "$exists") == 0) {
+      } else if (strcmp (key, "$gt") == 0) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_GT, path, &child);
+      } else if (strcmp (key, "$gte") == 0) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_GTE, path, &child);
+      } else if (strcmp (key, "$in") == 0) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_IN, path, &child);
+      } else if (strcmp (key, "$lt") == 0) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_LT, path, &child);
+      } else if (strcmp (key, "$lte") == 0) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_LTE, path, &child);
+      } else if (strcmp (key, "$ne") == 0) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_NE, path, &child);
+      } else if (strcmp (key, "$nin") == 0) {
+         op = _mongoc_matcher_op_compare_new (MONGOC_MATCHER_OPCODE_NIN, path, &child);
+      } else if (strcmp (key, "$exists") == 0) {
          op = _mongoc_matcher_op_exists_new (path, bson_iter_bool (&child));
-      } else if (strcmp(key, "$type") == 0) {
+      } else if (strcmp (key, "$type") == 0) {
          op = _mongoc_matcher_op_type_new (path, bson_iter_type (&child));
       } else {
-         bson_set_error (error,
-                         MONGOC_ERROR_MATCHER,
-                         MONGOC_ERROR_MATCHER_INVALID,
-                         "Invalid operator \"%s\"",
-                         key);
+         bson_set_error (error, MONGOC_ERROR_MATCHER, MONGOC_ERROR_MATCHER_INVALID, "Invalid operator \"%s\"", key);
          return NULL;
       }
    } else {
@@ -145,7 +125,7 @@ _mongoc_matcher_parse_compare (bson_iter_t  *iter,  /* IN */
  */
 
 static mongoc_matcher_op_t *
-_mongoc_matcher_parse (bson_iter_t  *iter,  /* IN */
+_mongoc_matcher_parse (bson_iter_t *iter,   /* IN */
                        bson_error_t *error) /* OUT */
 {
    bson_iter_t child;
@@ -158,34 +138,24 @@ _mongoc_matcher_parse (bson_iter_t  *iter,  /* IN */
    if (*key != '$') {
       return _mongoc_matcher_parse_compare (iter, key, error);
    } else {
-      BSON_ASSERT (bson_iter_type(iter) == BSON_TYPE_ARRAY);
+      BSON_ASSERT (bson_iter_type (iter) == BSON_TYPE_ARRAY);
 
       if (!bson_iter_recurse (iter, &child)) {
-         bson_set_error (error,
-                         MONGOC_ERROR_MATCHER,
-                         MONGOC_ERROR_MATCHER_INVALID,
-                         "Invalid value for operator \"%s\"",
-                         key);
+         bson_set_error (
+            error, MONGOC_ERROR_MATCHER, MONGOC_ERROR_MATCHER_INVALID, "Invalid value for operator \"%s\"", key);
          return NULL;
       }
 
       if (strcmp (key, "$or") == 0) {
-         return _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_OR,
-                                               &child, false, error);
-      } else if (strcmp(key, "$and") == 0) {
-         return _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_AND,
-                                               &child, false, error);
-      } else if (strcmp(key, "$nor") == 0) {
-         return _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_NOR,
-                                               &child, false, error);
+         return _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_OR, &child, false, error);
+      } else if (strcmp (key, "$and") == 0) {
+         return _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_AND, &child, false, error);
+      } else if (strcmp (key, "$nor") == 0) {
+         return _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_NOR, &child, false, error);
       }
    }
 
-   bson_set_error (error,
-                   MONGOC_ERROR_MATCHER,
-                   MONGOC_ERROR_MATCHER_INVALID,
-                   "Invalid operator \"%s\"",
-                   key);
+   bson_set_error (error, MONGOC_ERROR_MATCHER, MONGOC_ERROR_MATCHER_INVALID, "Invalid operator \"%s\"", key);
 
    return NULL;
 }
@@ -201,7 +171,7 @@ _mongoc_matcher_parse (bson_iter_t  *iter,  /* IN */
  *
  *       See the following link for more information.
  *
- *       http://docs.mongodb.org/manual/reference/operator/query/
+ *       https://www.mongodb.com/docs/manual/reference/operator/query/
  *
  * Returns:
  *       A newly allocated mongoc_matcher_op_t if successful; otherwise
@@ -214,10 +184,10 @@ _mongoc_matcher_parse (bson_iter_t  *iter,  /* IN */
  */
 
 static mongoc_matcher_op_t *
-_mongoc_matcher_parse_logical (mongoc_matcher_opcode_t  opcode,  /* IN */
-                               bson_iter_t             *iter,    /* IN */
-                               bool                     is_root, /* IN */
-                               bson_error_t            *error)   /* OUT */
+_mongoc_matcher_parse_logical (mongoc_matcher_opcode_t opcode, /* IN */
+                               bson_iter_t *iter,              /* IN */
+                               bool is_root,                   /* IN */
+                               bson_error_t *error)            /* OUT */
 {
    mongoc_matcher_op_t *left;
    mongoc_matcher_op_t *right;
@@ -230,10 +200,7 @@ _mongoc_matcher_parse_logical (mongoc_matcher_opcode_t  opcode,  /* IN */
    BSON_ASSERT (iter);
 
    if (!bson_iter_next (iter)) {
-      bson_set_error (error,
-                      MONGOC_ERROR_MATCHER,
-                      MONGOC_ERROR_MATCHER_INVALID,
-                      "Invalid logical operator.");
+      bson_set_error (error, MONGOC_ERROR_MATCHER, MONGOC_ERROR_MATCHER_INVALID, "Invalid logical operator.");
       return NULL;
    }
 
@@ -243,15 +210,19 @@ _mongoc_matcher_parse_logical (mongoc_matcher_opcode_t  opcode,  /* IN */
       }
    } else {
       if (!BSON_ITER_HOLDS_DOCUMENT (iter)) {
-         bson_set_error (error,
-                         MONGOC_ERROR_MATCHER,
-                         MONGOC_ERROR_MATCHER_INVALID,
-                         "Expected document in value.");
+         bson_set_error (error, MONGOC_ERROR_MATCHER, MONGOC_ERROR_MATCHER_INVALID, "Expected document in value.");
          return NULL;
       }
 
-      bson_iter_recurse (iter, &child);
-      bson_iter_next (&child);
+      if (!bson_iter_recurse (iter, &child)) {
+         bson_set_error (error, MONGOC_ERROR_BSON, MONGOC_ERROR_BSON_INVALID, "corrupt BSON");
+         return NULL;
+      }
+
+      if (!bson_iter_next (&child)) {
+         bson_set_error (error, MONGOC_ERROR_BSON, MONGOC_ERROR_BSON_INVALID, "corrupt BSON");
+         return NULL;
+      }
 
       if (!(left = _mongoc_matcher_parse (&child, error))) {
          return NULL;
@@ -268,15 +239,19 @@ _mongoc_matcher_parse_logical (mongoc_matcher_opcode_t  opcode,  /* IN */
       }
    } else {
       if (!BSON_ITER_HOLDS_DOCUMENT (iter)) {
-         bson_set_error (error,
-                         MONGOC_ERROR_MATCHER,
-                         MONGOC_ERROR_MATCHER_INVALID,
-                         "Expected document in value.");
+         bson_set_error (error, MONGOC_ERROR_MATCHER, MONGOC_ERROR_MATCHER_INVALID, "Expected document in value.");
          return NULL;
       }
 
-      bson_iter_recurse (iter, &child);
-      bson_iter_next (&child);
+      if (!bson_iter_recurse (iter, &child)) {
+         bson_set_error (error, MONGOC_ERROR_BSON, MONGOC_ERROR_BSON_INVALID, "bson_iter_recurse failed.");
+         return NULL;
+      }
+
+      if (!bson_iter_next (&child)) {
+         bson_set_error (error, MONGOC_ERROR_BSON, MONGOC_ERROR_BSON_INVALID, "corrupt BSON");
+         return NULL;
+      }
 
       if (!(right = _mongoc_matcher_parse (&child, error))) {
          return NULL;
@@ -328,15 +303,14 @@ mongoc_matcher_new (const bson_t *query, /* IN */
 
    BSON_ASSERT (query);
 
-   matcher = (mongoc_matcher_t *)bson_malloc0 (sizeof *matcher);
+   matcher = BSON_ALIGNED_ALLOC0 (mongoc_matcher_t);
    bson_copy_to (query, &matcher->query);
 
    if (!bson_iter_init (&iter, &matcher->query)) {
       goto failure;
    }
 
-   if (!(op = _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_AND, &iter,
-                                             true, error))) {
+   if (!(op = _mongoc_matcher_parse_logical (MONGOC_MATCHER_OPCODE_AND, &iter, true, error))) {
       goto failure;
    }
 
@@ -369,8 +343,8 @@ failure:
  */
 
 bool
-mongoc_matcher_match (const mongoc_matcher_t *matcher,  /* IN */
-                      const bson_t           *document) /* IN */
+mongoc_matcher_match (const mongoc_matcher_t *matcher, /* IN */
+                      const bson_t *document)          /* IN */
 {
    BSON_ASSERT (matcher);
    BSON_ASSERT (matcher->optree);
