@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,14 +14,14 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-config.h"
+#include "mongoc-config.h"
 
 #ifdef MONGOC_ENABLE_CRYPTO_COMMON_CRYPTO
 
-#include "mongoc/mongoc-rand.h"
-#include "mongoc/mongoc-rand-private.h"
+#include "mongoc-rand.h"
+#include "mongoc-rand-private.h"
 
-#include "mongoc/mongoc.h"
+#include "mongoc.h"
 #include <Security/Security.h>
 /* rumour has it this wasn't in standard Security.h in ~10.8 */
 #include <Security/SecRandom.h>
