@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -18,6 +18,7 @@
 #include "mongoc-error.h"
 #include "mongoc-read-prefs-private.h"
 #include "mongoc-trace-private.h"
+#include <common-cmp-private.h>
 
 
 mongoc_read_prefs_t *
@@ -43,8 +44,7 @@ mongoc_read_prefs_get_mode (const mongoc_read_prefs_t *read_prefs)
 
 
 void
-mongoc_read_prefs_set_mode (mongoc_read_prefs_t *read_prefs,
-                            mongoc_read_mode_t mode)
+mongoc_read_prefs_set_mode (mongoc_read_prefs_t *read_prefs, mongoc_read_mode_t mode)
 {
    BSON_ASSERT (read_prefs);
    BSON_ASSERT (mode <= MONGOC_READ_NEAREST);
@@ -86,7 +86,9 @@ mongoc_read_prefs_add_tag (mongoc_read_prefs_t *read_prefs, const bson_t *tag)
    BSON_ASSERT (read_prefs);
 
    key = bson_count_keys (&read_prefs->tags);
-   bson_snprintf (str, sizeof str, "%d", key);
+   // Expect no truncation.
+   int req = bson_snprintf (str, sizeof str, "%d", key);
+   BSON_ASSERT (mcommon_cmp_less_su (req, sizeof str));
 
    if (tag) {
       bson_append_document (&read_prefs->tags, str, -1, tag);
@@ -99,8 +101,7 @@ mongoc_read_prefs_add_tag (mongoc_read_prefs_t *read_prefs, const bson_t *tag)
 
 
 int64_t
-mongoc_read_prefs_get_max_staleness_seconds (
-   const mongoc_read_prefs_t *read_prefs)
+mongoc_read_prefs_get_max_staleness_seconds (const mongoc_read_prefs_t *read_prefs)
 {
    BSON_ASSERT (read_prefs);
 
@@ -109,8 +110,7 @@ mongoc_read_prefs_get_max_staleness_seconds (
 
 
 void
-mongoc_read_prefs_set_max_staleness_seconds (mongoc_read_prefs_t *read_prefs,
-                                             int64_t max_staleness_seconds)
+mongoc_read_prefs_set_max_staleness_seconds (mongoc_read_prefs_t *read_prefs, int64_t max_staleness_seconds)
 {
    BSON_ASSERT (read_prefs);
 
@@ -128,8 +128,7 @@ mongoc_read_prefs_get_hedge (const mongoc_read_prefs_t *read_prefs)
 
 
 void
-mongoc_read_prefs_set_hedge (mongoc_read_prefs_t *read_prefs,
-                             const bson_t *hedge)
+mongoc_read_prefs_set_hedge (mongoc_read_prefs_t *read_prefs, const bson_t *hedge)
 {
    BSON_ASSERT (read_prefs);
 
@@ -152,15 +151,13 @@ mongoc_read_prefs_is_valid (const mongoc_read_prefs_t *read_prefs)
     * Tags, maxStalenessSeconds, and hedge are not supported with PRIMARY mode.
     */
    if (read_prefs->mode == MONGOC_READ_PRIMARY) {
-      if (!bson_empty (&read_prefs->tags) ||
-          read_prefs->max_staleness_seconds != MONGOC_NO_MAX_STALENESS ||
+      if (!bson_empty (&read_prefs->tags) || read_prefs->max_staleness_seconds != MONGOC_NO_MAX_STALENESS ||
           !bson_empty (&read_prefs->hedge)) {
          return false;
       }
    }
 
-   if (read_prefs->max_staleness_seconds != MONGOC_NO_MAX_STALENESS &&
-       read_prefs->max_staleness_seconds <= 0) {
+   if (read_prefs->max_staleness_seconds != MONGOC_NO_MAX_STALENESS && read_prefs->max_staleness_seconds <= 0) {
       return false;
    }
 
@@ -222,10 +219,9 @@ _mongoc_read_mode_as_str (mongoc_read_mode_t mode)
  * The driver must have discovered the server is a mongos.
  */
 static void
-_apply_read_preferences_mongos (
-   const mongoc_read_prefs_t *read_prefs,
-   const bson_t *query_bson,
-   mongoc_assemble_query_result_t *result /* OUT */)
+_apply_read_preferences_mongos (const mongoc_read_prefs_t *read_prefs,
+                                const bson_t *query_bson,
+                                mongoc_assemble_query_result_t *result /* OUT */)
 {
    mongoc_read_mode_t mode;
    const bson_t *tags = NULL;
@@ -236,8 +232,7 @@ _apply_read_preferences_mongos (
 
    mode = mongoc_read_prefs_get_mode (read_prefs);
    if (read_prefs) {
-      max_staleness_seconds =
-         mongoc_read_prefs_get_max_staleness_seconds (read_prefs);
+      max_staleness_seconds = mongoc_read_prefs_get_max_staleness_seconds (read_prefs);
 
       tags = mongoc_read_prefs_get_tags (read_prefs);
       hedge = mongoc_read_prefs_get_hedge (read_prefs);
@@ -264,8 +259,7 @@ _apply_read_preferences_mongos (
     * and MUST also use $readPreference
     */
    if (mode == MONGOC_READ_SECONDARY_PREFERRED &&
-       (bson_empty0 (tags) && max_staleness_seconds <= 0 &&
-        bson_empty0 (hedge))) {
+       (bson_empty0 (tags) && max_staleness_seconds <= 0 && bson_empty0 (hedge))) {
       result->flags |= MONGOC_QUERY_SECONDARY_OK;
 
    } else if (mode != MONGOC_READ_PRIMARY) {
@@ -283,12 +277,10 @@ _apply_read_preferences_mongos (
       if (bson_has_field (query_bson, "$query")) {
          bson_concat (result->assembled_query, query_bson);
       } else {
-         bson_append_document (
-            result->assembled_query, "$query", 6, query_bson);
+         bson_append_document (result->assembled_query, "$query", 6, query_bson);
       }
 
-      bson_append_document_begin (
-         result->assembled_query, "$readPreference", 15, &child);
+      bson_append_document_begin (result->assembled_query, "$readPreference", 15, &child);
       mode_str = _mongoc_read_mode_as_str (mode);
       bson_append_utf8 (&child, "mode", 4, mode_str, -1);
       if (!bson_empty0 (tags)) {
@@ -296,8 +288,7 @@ _apply_read_preferences_mongos (
       }
 
       if (max_staleness_seconds != MONGOC_NO_MAX_STALENESS) {
-         bson_append_int64 (
-            &child, "maxStalenessSeconds", 19, max_staleness_seconds);
+         bson_append_int64 (&child, "maxStalenessSeconds", 19, max_staleness_seconds);
       }
 
       if (!bson_empty0 (hedge)) {
@@ -332,7 +323,7 @@ void
 assemble_query (const mongoc_read_prefs_t *read_prefs,
                 const mongoc_server_stream_t *server_stream,
                 const bson_t *query_bson,
-                mongoc_query_flags_t initial_flags,
+                int32_t initial_flags,
                 mongoc_assemble_query_result_t *result /* OUT */)
 {
    mongoc_server_description_type_t server_type;
@@ -360,7 +351,7 @@ assemble_query (const mongoc_read_prefs_t *read_prefs,
           * protocol flag on reads to ensure that any server type can handle the
           * request."
           */
-         result->flags |= MONGOC_QUERY_SECONDARY_OK;
+         result->flags |= MONGOC_OP_QUERY_FLAG_SECONDARY_OK;
       }
 
       break;
@@ -374,7 +365,7 @@ assemble_query (const mongoc_read_prefs_t *read_prefs,
        * the read preference mode is primary.
        */
       if (read_prefs && read_prefs->mode != MONGOC_READ_PRIMARY) {
-         result->flags |= MONGOC_QUERY_SECONDARY_OK;
+         result->flags |= MONGOC_OP_QUERY_FLAG_SECONDARY_OK;
       }
 
       break;
@@ -410,14 +401,10 @@ assemble_query_result_cleanup (mongoc_assemble_query_result_t *result)
 }
 
 bool
-_mongoc_read_prefs_validate (const mongoc_read_prefs_t *read_prefs,
-                             bson_error_t *error)
+_mongoc_read_prefs_validate (const mongoc_read_prefs_t *read_prefs, bson_error_t *error)
 {
    if (read_prefs && !mongoc_read_prefs_is_valid (read_prefs)) {
-      bson_set_error (error,
-                      MONGOC_ERROR_COMMAND,
-                      MONGOC_ERROR_COMMAND_INVALID_ARG,
-                      "Invalid mongoc_read_prefs_t");
+      bson_set_error (error, MONGOC_ERROR_COMMAND, MONGOC_ERROR_COMMAND_INVALID_ARG, "Invalid mongoc_read_prefs_t");
       return false;
    }
    return true;
