@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,13 +14,12 @@
  * limitations under the License.
  */
 
+#include "mongoc-prelude.h"
+
 #ifndef MONGOC_STREAM_FILE_H
 #define MONGOC_STREAM_FILE_H
 
-#if !defined(MONGOC_INSIDE) && !defined(MONGOC_COMPILATION)
-#error "Only <mongoc.h> can be included directly."
-#endif
-
+#include "mongoc-macros.h"
 #include "mongoc-stream.h"
 
 
@@ -30,11 +29,11 @@ BSON_BEGIN_DECLS
 typedef struct _mongoc_stream_file_t mongoc_stream_file_t;
 
 
-BSON_EXPORT (mongoc_stream_t *)
-mongoc_stream_file_new (int fd);
-BSON_EXPORT (mongoc_stream_t *)
-mongoc_stream_file_new_for_path (const char *path, int flags, int mode);
-BSON_EXPORT (int)
+MONGOC_EXPORT (mongoc_stream_t *)
+mongoc_stream_file_new (int fd) BSON_GNUC_WARN_UNUSED_RESULT;
+MONGOC_EXPORT (mongoc_stream_t *)
+mongoc_stream_file_new_for_path (const char *path, int flags, int mode) BSON_GNUC_WARN_UNUSED_RESULT;
+MONGOC_EXPORT (int)
 mongoc_stream_file_get_fd (mongoc_stream_file_t *stream);
 
 
