@@ -1,5 +1,5 @@
 /*
- * Copyright 2013-2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -38,11 +38,8 @@ bool
 mongoc_stream_wait (mongoc_stream_t *stream, int64_t expire_at);
 
 bool
-_mongoc_stream_writev_full (mongoc_stream_t *stream,
-                            mongoc_iovec_t *iov,
-                            size_t iovcnt,
-                            int32_t timeout_msec,
-                            bson_error_t *error);
+_mongoc_stream_writev_full (
+   mongoc_stream_t *stream, mongoc_iovec_t *iov, size_t iovcnt, int64_t timeout_msec, bson_error_t *error);
 
 mongoc_stream_t *
 mongoc_stream_get_root_stream (mongoc_stream_t *stream);
