@@ -1,5 +1,5 @@
 /*
- * Copyright 2016 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
  * limitations under the License.
  */
 
-#include "mongoc/mongoc-prelude.h"
+#include "mongoc-prelude.h"
 
 #ifndef MONGOC_STREAM_TLS_OPENSSL_BIO_PRIVATE_H
 #define MONGOC_STREAM_TLS_OPENSSL_BIO_PRIVATE_H
@@ -29,7 +29,7 @@
 BSON_BEGIN_DECLS
 
 BIO_METHOD *
-mongoc_stream_tls_openssl_bio_meth_new ();
+mongoc_stream_tls_openssl_bio_meth_new (void);
 
 void
 mongoc_stream_tls_openssl_bio_set_data (BIO *b, void *ptr);
