@@ -1,5 +1,5 @@
 /*
- * Copyright 2014 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -29,6 +29,8 @@
 #include "mongoc-crypt-private.h"
 #include "mongoc-ts-pool-private.h"
 #include "mongoc-shared-private.h"
+#include "mongoc-sleep.h"
+#include <common-atomic-private.h>
 
 #define MONGOC_TOPOLOGY_MIN_HEARTBEAT_FREQUENCY_MS 500
 #define MONGOC_TOPOLOGY_SOCKET_CHECK_INTERVAL_MS 5000
@@ -72,19 +74,19 @@ typedef struct _mongoc_rr_data_t {
 
 struct _mongoc_topology_t;
 
-MONGOC_DECL_SPECIAL_TS_POOL (
-   mongoc_server_session_t,
-   mongoc_server_session_pool,
-   struct _mongoc_topology_t,
-   /* ctor/dtor/prune are defined in the new_with_params call */
-   NULL,
-   NULL,
-   NULL)
+MONGOC_DECL_SPECIAL_TS_POOL (mongoc_server_session_t,
+                             mongoc_server_session_pool,
+                             struct _mongoc_topology_t,
+                             /* ctor/dtor/prune are defined in the new_with_params call */
+                             NULL,
+                             NULL,
+                             NULL)
 
 typedef bool (*_mongoc_rr_resolver_fn) (const char *hostname,
                                         mongoc_rr_type_t rr_type,
                                         mongoc_rr_data_t *rr_data,
                                         size_t initial_buffer_size,
+                                        bool prefer_tcp,
                                         bson_error_t *error);
 
 /**
@@ -127,8 +129,10 @@ typedef struct _mongoc_topology_t {
    int64_t min_heartbeat_frequency_msec;
 
    /* Minimum of SRV record TTLs, but no lower than 60 seconds.
-    * May be zero for non-SRV/non-MongoS topology. */
-   int64_t srv_polling_rescan_interval_ms;
+    * May be zero for non-SRV/non-MongoS topology.
+    * DO NOT access directly: use the accessor methods to get/set the value.
+    */
+   int64_t _atomic_srv_polling_rescan_interval_ms;
    int64_t srv_polling_last_scan_ms;
    /* For multi-threaded, srv polling occurs in a separate thread. */
    bson_thread_t srv_polling_thread;
@@ -185,8 +189,21 @@ typedef struct _mongoc_topology_t {
    bool mongocryptd_bypass_spawn;
    char *mongocryptd_spawn_path;
    bson_t *mongocryptd_spawn_args;
+   bool bypass_query_analysis;
 #endif
 
+   struct {
+      struct {
+         struct {
+            char *cryptSharedLibPath;
+            bool cryptSharedLibRequired;
+         } extraOptions;
+      } autoOptions;
+   } clientSideEncryption;
+
+   // Corresponds to AutoEncryptionOpts.encryptedFieldsMap.
+   bson_t *encrypted_fields_map;
+
    /* For background monitoring. */
    mongoc_set_t *server_monitors;
    mongoc_set_t *rtt_monitors;
@@ -199,6 +216,16 @@ typedef struct _mongoc_topology_t {
     * topology. This could occur if the URI is invalid.
     * An invalid topology does not monitor servers. */
    bool valid;
+
+   // `usleep_fn` and `usleep_data` may be overridden by
+   // `mongoc_client_set_usleep_impl`.
+   mongoc_usleep_func_t usleep_fn;
+   void *usleep_data;
+
+   // `srv_prefer_tcp` determines if DNS lookup for SRV tries TCP first instead of UDP.
+   // DNS implementations are expected to try UDP first, then retry with TCP if the UDP response indicates truncation.
+   // Some DNS servers truncate UDP responses without setting the truncated (TC) flag. This may result in no TCP retry.
+   bool srv_prefer_tcp;
 } mongoc_topology_t;
 
 mongoc_topology_t *
@@ -207,15 +234,14 @@ mongoc_topology_new (const mongoc_uri_t *uri, bool single_threaded);
 void
 mongoc_topology_set_apm_callbacks (mongoc_topology_t *topology,
                                    mongoc_topology_description_t *td,
-                                   mongoc_apm_callbacks_t *callbacks,
+                                   mongoc_apm_callbacks_t const *callbacks,
                                    void *context);
 
 void
 mongoc_topology_destroy (mongoc_topology_t *topology);
 
 void
-mongoc_topology_reconcile (const mongoc_topology_t *topology,
-                           mongoc_topology_description_t *td);
+mongoc_topology_reconcile (const mongoc_topology_t *topology, mongoc_topology_description_t *td);
 
 bool
 mongoc_topology_compatible (const mongoc_topology_description_t *td,
@@ -265,6 +291,8 @@ mongoc_topology_select (mongoc_topology_t *topology,
  * @param must_use_primary An optional output parameter. Server selection might
  * need to override the caller's read preferences' read mode to 'primary'.
  * Whether or not that takes place will be set through this pointer.
+ * @param ds A list of servers that should be selected only if there are no
+ * other suitable servers.
  * @param error An output parameter for any error information.
  * @return uint32_t A non-zero integer ID of the server description. In case of
  * error, sets `error` and returns zero.
@@ -276,6 +304,7 @@ mongoc_topology_select_server_id (mongoc_topology_t *topology,
                                   mongoc_ss_optype_t optype,
                                   const mongoc_read_prefs_t *read_prefs,
                                   bool *must_use_primary,
+                                  const mongoc_deprioritized_servers_t *ds,
                                   bson_error_t *error);
 
 /**
@@ -291,9 +320,7 @@ mongoc_topology_select_server_id (mongoc_topology_t *topology,
  * `_mongoc_host_list_destroy_all()`
  */
 mongoc_host_list_t *
-_mongoc_topology_host_by_id (const mongoc_topology_description_t *topology,
-                             uint32_t id,
-                             bson_error_t *error);
+_mongoc_topology_host_by_id (const mongoc_topology_description_t *topology, uint32_t id, bson_error_t *error);
 
 /**
  * @brief Update the topology from the response to a handshake on a new
@@ -308,12 +335,10 @@ _mongoc_topology_host_by_id (const mongoc_topology_description_t *topology,
  * @return false If the server was already removed from the topology.
  */
 bool
-_mongoc_topology_update_from_handshake (mongoc_topology_t *topology,
-                                        const mongoc_server_description_t *sd);
+_mongoc_topology_update_from_handshake (mongoc_topology_t *topology, const mongoc_server_description_t *sd);
 
 void
-_mongoc_topology_update_last_used (mongoc_topology_t *topology,
-                                   uint32_t server_id);
+_mongoc_topology_update_last_used (mongoc_topology_t *topology, uint32_t server_id);
 
 int64_t
 mongoc_topology_server_timestamp (mongoc_topology_t *topology, uint32_t id);
@@ -328,23 +353,19 @@ bool
 _mongoc_topology_set_appname (mongoc_topology_t *topology, const char *appname);
 
 void
-_mongoc_topology_update_cluster_time (mongoc_topology_t *topology,
-                                      const bson_t *reply);
+_mongoc_topology_update_cluster_time (mongoc_topology_t *topology, const bson_t *reply);
 
 mongoc_server_session_t *
-_mongoc_topology_pop_server_session (mongoc_topology_t *topology,
-                                     bson_error_t *error);
+_mongoc_topology_pop_server_session (mongoc_topology_t *topology, bson_error_t *error);
 
 void
-_mongoc_topology_push_server_session (mongoc_topology_t *topology,
-                                      mongoc_server_session_t *server_session);
+_mongoc_topology_push_server_session (mongoc_topology_t *topology, mongoc_server_session_t *server_session);
 
 bool
 _mongoc_topology_end_sessions_cmd (mongoc_topology_t *topology, bson_t *cmd);
 
 void
-_mongoc_topology_do_blocking_scan (mongoc_topology_t *topology,
-                                   bson_error_t *error);
+_mongoc_topology_do_blocking_scan (mongoc_topology_t *topology, bson_error_t *error);
 
 /**
  * @brief Duplicate the handshake command of the topology scanner.
@@ -361,8 +382,7 @@ _mongoc_topology_do_blocking_scan (mongoc_topology_t *topology,
  * node in _mongoc_stream_run_hello.
  */
 void
-_mongoc_topology_dup_handshake_cmd (const mongoc_topology_t *topology,
-                                    bson_t *copy_into);
+_mongoc_topology_dup_handshake_cmd (const mongoc_topology_t *topology, bson_t *copy_into);
 void
 _mongoc_topology_request_scan (mongoc_topology_t *topology);
 
@@ -421,16 +441,25 @@ mongoc_topology_should_rescan_srv (mongoc_topology_t *topology);
  * Callers should call this before monitoring starts.
  */
 void
-_mongoc_topology_set_rr_resolver (mongoc_topology_t *topology,
-                                  _mongoc_rr_resolver_fn rr_resolver);
+_mongoc_topology_set_rr_resolver (mongoc_topology_t *topology, _mongoc_rr_resolver_fn rr_resolver);
 
-/* _mongoc_topology_set_srv_polling_rescan_interval_ms is called by tests to
- * shorten the rescan interval.
- * Callers should call this before monitoring starts.
+/**
+ * @brief Thread-safe update the SRV polling rescan interval on the given topology
  */
-void
-_mongoc_topology_set_srv_polling_rescan_interval_ms (
-   mongoc_topology_t *topology, int64_t val);
+static BSON_INLINE void
+_mongoc_topology_set_srv_polling_rescan_interval_ms (mongoc_topology_t *topology, int64_t val)
+{
+   mcommon_atomic_int64_exchange (&topology->_atomic_srv_polling_rescan_interval_ms, val, mcommon_memory_order_seq_cst);
+}
+
+/**
+ * @brief Thread-safe get the SRV polling interval
+ */
+static BSON_INLINE int64_t
+_mongoc_topology_get_srv_polling_rescan_interval_ms (mongoc_topology_t const *topology)
+{
+   return mcommon_atomic_int64_fetch (&topology->_atomic_srv_polling_rescan_interval_ms, mcommon_memory_order_seq_cst);
+}
 
 /**
  * @brief Return the latest connection generation for the server_id and/or
@@ -446,10 +475,9 @@ _mongoc_topology_set_srv_polling_rescan_interval_ms (
  * server does not exist in the topology.
  */
 uint32_t
-_mongoc_topology_get_connection_pool_generation (
-   const mongoc_topology_description_t *td,
-   uint32_t server_id,
-   const bson_oid_t *service_id);
+_mongoc_topology_get_connection_pool_generation (const mongoc_topology_description_t *td,
+                                                 uint32_t server_id,
+                                                 const bson_oid_t *service_id);
 
 /**
  * @brief Obtain a reference to the current topology description for the given
@@ -462,8 +490,7 @@ _mongoc_topology_get_connection_pool_generation (
 static BSON_INLINE mc_shared_tpld
 mc_tpld_take_ref (const mongoc_topology_t *tpl)
 {
-   return (mc_shared_tpld){
-      ._sptr_ = mongoc_atomic_shared_ptr_load (&tpl->_shared_descr_._sptr_)};
+   return (mc_shared_tpld){._sptr_ = mongoc_atomic_shared_ptr_load (&tpl->_shared_descr_._sptr_)};
 }
 
 /**
@@ -589,10 +616,8 @@ _mongoc_topology_invalidate_server (mongoc_topology_t *td, uint32_t server_id)
 {
    bson_error_t error;
    mc_tpld_modification tdmod = mc_tpld_modify_begin (td);
-   bson_set_error (
-      &error, MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_CONNECT, "invalidated");
-   mongoc_topology_description_invalidate_server (
-      tdmod.new_td, server_id, &error);
+   bson_set_error (&error, MONGOC_ERROR_STREAM, MONGOC_ERROR_STREAM_CONNECT, "invalidated");
+   mongoc_topology_description_invalidate_server (tdmod.new_td, server_id, &error);
    mc_tpld_modify_commit (tdmod);
 }
 
@@ -604,8 +629,18 @@ _mongoc_topology_invalidate_server (mongoc_topology_t *td, uint32_t server_id)
  * array must not be freed, as they are still owned by `hl`.
  */
 const mongoc_host_list_t **
-_mongoc_apply_srv_max_hosts (const mongoc_host_list_t *hl,
-                             int32_t max_hosts,
-                             size_t *hl_array_size);
+_mongoc_apply_srv_max_hosts (const mongoc_host_list_t *hl, size_t max_hosts, size_t *hl_array_size);
+
+
+/* Returns true if a versioned server API has been selected, otherwise returns
+ * false. */
+bool
+mongoc_topology_uses_server_api (const mongoc_topology_t *topology);
+
+
+/* Returns true if load balancing mode has been seelected, otherwise returns
+ * false. */
+bool
+mongoc_topology_uses_loadbalanced (const mongoc_topology_t *topology);
 
 #endif
