@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -27,20 +27,20 @@
 #include "mongoc-rand-private.h"
 #include "mongoc-util-private.h"
 #include "mongoc-client.h"
+#include "mongoc-client-private.h" // WIRE_VERSION_* macros.
 #include "mongoc-client-session-private.h"
 #include "mongoc-trace-private.h"
+#include "mongoc-sleep.h"
+#include <common-cmp-private.h>
 
 const bson_validate_flags_t _mongoc_default_insert_vflags =
-   BSON_VALIDATE_UTF8 | BSON_VALIDATE_UTF8_ALLOW_NULL |
-   BSON_VALIDATE_EMPTY_KEYS;
+   BSON_VALIDATE_UTF8 | BSON_VALIDATE_UTF8_ALLOW_NULL | BSON_VALIDATE_EMPTY_KEYS;
 
 const bson_validate_flags_t _mongoc_default_replace_vflags =
-   BSON_VALIDATE_UTF8 | BSON_VALIDATE_UTF8_ALLOW_NULL |
-   BSON_VALIDATE_EMPTY_KEYS;
+   BSON_VALIDATE_UTF8 | BSON_VALIDATE_UTF8_ALLOW_NULL | BSON_VALIDATE_EMPTY_KEYS;
 
 const bson_validate_flags_t _mongoc_default_update_vflags =
-   BSON_VALIDATE_UTF8 | BSON_VALIDATE_UTF8_ALLOW_NULL |
-   BSON_VALIDATE_EMPTY_KEYS;
+   BSON_VALIDATE_UTF8 | BSON_VALIDATE_UTF8_ALLOW_NULL | BSON_VALIDATE_EMPTY_KEYS;
 
 int
 _mongoc_rand_simple (unsigned int *seed)
@@ -71,22 +71,31 @@ _mongoc_hex_md5 (const char *input)
    int i;
 
    mcommon_md5_init (&md5);
-   mcommon_md5_append (
-      &md5, (const uint8_t *) input, (uint32_t) strlen (input));
+   mcommon_md5_append (&md5, (const uint8_t *) input, (uint32_t) strlen (input));
    mcommon_md5_finish (&md5, digest);
 
    for (i = 0; i < sizeof digest; i++) {
-      bson_snprintf (&digest_str[i * 2], 3, "%02x", digest[i]);
+      // Expect no truncation.
+      int req = bson_snprintf (&digest_str[i * 2], 3, "%02x", digest[i]);
+      BSON_ASSERT (req < 3);
    }
    digest_str[sizeof digest_str - 1] = '\0';
 
    return bson_strdup (digest_str);
 }
 
+void
+mongoc_client_set_usleep_impl (mongoc_client_t *client, mongoc_usleep_func_t usleep_func, void *user_data)
+{
+   client->topology->usleep_fn = usleep_func;
+   client->topology->usleep_data = user_data;
+}
 
 void
-_mongoc_usleep (int64_t usec)
+mongoc_usleep_default_impl (int64_t usec, void *user_data)
 {
+   BSON_UNUSED (user_data);
+
 #ifdef _WIN32
    LARGE_INTEGER ft;
    HANDLE timer;
@@ -104,6 +113,13 @@ _mongoc_usleep (int64_t usec)
 #endif
 }
 
+void
+_mongoc_usleep (int64_t usec)
+{
+   mongoc_usleep_default_impl (usec, NULL);
+}
+
+
 int64_t
 _mongoc_get_real_time_ms (void)
 {
@@ -142,34 +158,14 @@ _mongoc_get_command_name (const bson_t *command)
       wrapper_name = "query";
    }
 
-   if (wrapper_name && bson_iter_init_find (&iter, command, wrapper_name) &&
-       BSON_ITER_HOLDS_DOCUMENT (&iter) && bson_iter_recurse (&iter, &child) &&
-       bson_iter_next (&child)) {
+   if (wrapper_name && bson_iter_init_find (&iter, command, wrapper_name) && BSON_ITER_HOLDS_DOCUMENT (&iter) &&
+       bson_iter_recurse (&iter, &child) && bson_iter_next (&child)) {
       name = bson_iter_key (&child);
    }
 
    return name;
 }
 
-
-const char *
-_mongoc_get_documents_field_name (const char *command_name)
-{
-   if (!strcmp (command_name, "insert")) {
-      return "documents";
-   }
-
-   if (!strcmp (command_name, "update")) {
-      return "updates";
-   }
-
-   if (!strcmp (command_name, "delete")) {
-      return "deletes";
-   }
-
-   return NULL;
-}
-
 bool
 _mongoc_lookup_bool (const bson_t *bson, const char *key, bool default_value)
 {
@@ -269,7 +265,7 @@ _mongoc_bson_type_to_str (bson_type_t t)
 
 
 /* Refer to:
- * https://github.com/mongodb/specifications/blob/master/source/wireversion-featurelist.rst
+ * https://github.com/mongodb/specifications/blob/master/source/wireversion-featurelist/wireversion-featurelist.md
  * and:
  * https://github.com/mongodb/mongo/blob/master/src/mongo/db/wire_version.h#L57
  */
@@ -288,28 +284,32 @@ _mongoc_wire_version_to_server_version (int32_t version)
       return "3.4";
    case 6:
       return "3.6";
-   case 7:
+   case WIRE_VERSION_4_0:
       return "4.0";
-   case 8:
+   case WIRE_VERSION_4_2:
       return "4.2";
-   case 9:
+   case WIRE_VERSION_4_4:
       return "4.4";
    case 10:
       return "4.7";
    case 11:
       return "4.8";
-   case 12:
+   case WIRE_VERSION_4_9:
       return "4.9";
-   case 13:
+   case WIRE_VERSION_5_0:
       return "5.0";
-   case 14:
+   case WIRE_VERSION_5_1:
       return "5.1";
    case 15:
       return "5.2";
    case 16:
       return "5.3";
-   case 17:
+   case WIRE_VERSION_6_0:
       return "6.0";
+   case WIRE_VERSION_7_0:
+      return "7.0";
+   case WIRE_VERSION_8_0:
+      return "8.0";
    default:
       return "Unknown";
    }
@@ -320,11 +320,8 @@ _mongoc_wire_version_to_server_version (int32_t version)
  * if absent. On error, fills out *error with domain and code and return false.
  */
 bool
-_mongoc_get_server_id_from_opts (const bson_t *opts,
-                                 mongoc_error_domain_t domain,
-                                 mongoc_error_code_t code,
-                                 uint32_t *server_id,
-                                 bson_error_t *error)
+_mongoc_get_server_id_from_opts (
+   const bson_t *opts, mongoc_error_domain_t domain, mongoc_error_code_t code, uint32_t *server_id, bson_error_t *error)
 {
    bson_iter_t iter;
 
@@ -339,8 +336,7 @@ _mongoc_get_server_id_from_opts (const bson_t *opts,
    }
 
    if (!BSON_ITER_HOLDS_INT (&iter)) {
-      bson_set_error (
-         error, domain, code, "The serverId option must be an integer");
+      bson_set_error (error, domain, code, "The serverId option must be an integer");
       RETURN (false);
    }
 
@@ -356,9 +352,7 @@ _mongoc_get_server_id_from_opts (const bson_t *opts,
 
 
 bool
-_mongoc_validate_new_document (const bson_t *doc,
-                               bson_validate_flags_t vflags,
-                               bson_error_t *error)
+_mongoc_validate_new_document (const bson_t *doc, bson_validate_flags_t vflags, bson_error_t *error)
 {
    bson_error_t validate_err;
 
@@ -380,9 +374,7 @@ _mongoc_validate_new_document (const bson_t *doc,
 
 
 bool
-_mongoc_validate_replace (const bson_t *doc,
-                          bson_validate_flags_t vflags,
-                          bson_error_t *error)
+_mongoc_validate_replace (const bson_t *doc, bson_validate_flags_t vflags, bson_error_t *error)
 {
    bson_error_t validate_err;
    bson_iter_t iter;
@@ -402,10 +394,7 @@ _mongoc_validate_replace (const bson_t *doc,
    }
 
    if (!bson_iter_init (&iter, doc)) {
-      bson_set_error (error,
-                      MONGOC_ERROR_BSON,
-                      MONGOC_ERROR_BSON_INVALID,
-                      "replace document is corrupt");
+      bson_set_error (error, MONGOC_ERROR_BSON, MONGOC_ERROR_BSON_INVALID, "replace document is corrupt");
       return false;
    }
 
@@ -427,9 +416,7 @@ _mongoc_validate_replace (const bson_t *doc,
 
 
 bool
-_mongoc_validate_update (const bson_t *update,
-                         bson_validate_flags_t vflags,
-                         bson_error_t *error)
+_mongoc_validate_update (const bson_t *update, bson_validate_flags_t vflags, bson_error_t *error)
 {
    bson_error_t validate_err;
    bson_iter_t iter;
@@ -453,10 +440,7 @@ _mongoc_validate_update (const bson_t *update,
    }
 
    if (!bson_iter_init (&iter, update)) {
-      bson_set_error (error,
-                      MONGOC_ERROR_BSON,
-                      MONGOC_ERROR_BSON_INVALID,
-                      "update document is corrupt");
+      bson_set_error (error, MONGOC_ERROR_BSON, MONGOC_ERROR_BSON_INVALID, "update document is corrupt");
       return false;
    }
 
@@ -477,6 +461,91 @@ _mongoc_validate_update (const bson_t *update,
    return true;
 }
 
+
+static bool
+should_include (const char *first_include, va_list args, const char *name)
+{
+   bool ret = false;
+   const char *include = first_include;
+   va_list args_copy;
+
+   va_copy (args_copy, args);
+
+   do {
+      if (!strcmp (name, include)) {
+         ret = true;
+         break;
+      }
+   } while ((include = va_arg (args_copy, const char *)));
+
+   va_end (args_copy);
+
+   return ret;
+}
+
+
+void
+bson_copy_to_including_noinit_va (const bson_t *src, bson_t *dst, const char *first_include, va_list args)
+{
+   BSON_ASSERT_PARAM (src);
+   BSON_ASSERT_PARAM (dst);
+   BSON_ASSERT_PARAM (first_include);
+   bson_iter_t iter;
+
+   if (bson_iter_init (&iter, src)) {
+      while (bson_iter_next (&iter)) {
+         if (should_include (first_include, args, bson_iter_key (&iter))) {
+            if (!bson_append_iter (dst, NULL, 0, &iter)) {
+               /*
+                * This should not be able to happen since we are copying
+                * from within a valid bson_t.
+                */
+               BSON_ASSERT (false);
+               return;
+            }
+         }
+      }
+   }
+}
+
+void
+bson_copy_to_including_noinit (const bson_t *src, bson_t *dst, const char *first_include, ...)
+{
+   BSON_ASSERT_PARAM (src);
+   BSON_ASSERT_PARAM (dst);
+   BSON_ASSERT_PARAM (first_include);
+
+   va_list args;
+   va_start (args, first_include);
+   bson_copy_to_including_noinit_va (src, dst, first_include, args);
+   va_end (args);
+}
+
+/*
+ *--------------------------------------------------------------------------
+ *
+ * mongoc_ends_with --
+ *
+ *       Return true if str ends with suffix.
+ *
+ *--------------------------------------------------------------------------
+ */
+bool
+mongoc_ends_with (const char *str, const char *suffix)
+{
+   BSON_ASSERT_PARAM (str);
+   BSON_ASSERT_PARAM (suffix);
+
+   const size_t str_len = strlen (str);
+   const size_t suffix_len = strlen (suffix);
+
+   if (str_len < suffix_len) {
+      return false;
+   }
+
+   return strcmp (str + (str_len - suffix_len), suffix) == 0;
+}
+
 void
 mongoc_lowercase (const char *src, char *buf /* OUT */)
 {
@@ -576,10 +645,10 @@ _mongoc_bson_array_copy_labels_to (const bson_t *reply, bson_t *dst)
 
 /*--------------------------------------------------------------------------
  *
- * _mongoc_bson_init_with_transient_txn_error --
+ * _mongoc_add_transient_txn_error --
  *
- *       If @reply is not NULL, initialize it. If @cs is not NULL and in a
- *       transaction, add errorLabels: ["TransientTransactionError"] to @cs.
+ *       If @cs is not NULL and in a transaction, add errorLabels:
+ *       ["TransientTransactionError"] to @reply.
  *
  *       Transactions Spec: TransientTransactionError includes "server
  *       selection error encountered running any command besides
@@ -594,21 +663,26 @@ _mongoc_bson_array_copy_labels_to (const bson_t *reply, bson_t *dst)
  */
 
 void
-_mongoc_bson_init_with_transient_txn_error (const mongoc_client_session_t *cs,
-                                            bson_t *reply)
+_mongoc_add_transient_txn_error (const mongoc_client_session_t *cs, bson_t *reply)
 {
-   bson_t labels;
-
    if (!reply) {
       return;
    }
 
-   bson_init (reply);
-
    if (_mongoc_client_session_in_txn (cs)) {
-      BSON_APPEND_ARRAY_BEGIN (reply, "errorLabels", &labels);
-      BSON_APPEND_UTF8 (&labels, "0", TRANSIENT_TXN_ERR);
-      bson_append_array_end (reply, &labels);
+      bson_t labels = BSON_INITIALIZER;
+      _mongoc_bson_array_copy_labels_to (reply, &labels);
+      _mongoc_bson_array_add_label (&labels, TRANSIENT_TXN_ERR);
+
+      bson_t new_reply = BSON_INITIALIZER;
+      bson_copy_to_excluding_noinit (reply, &new_reply, "errorLabels", NULL);
+      BSON_APPEND_ARRAY (&new_reply, "errorLabels", &labels);
+
+      bson_reinit (reply);
+      bson_concat (reply, &new_reply);
+
+      bson_destroy (&labels);
+      bson_destroy (&new_reply);
    }
 }
 
@@ -669,9 +743,9 @@ _mongoc_getenv (const char *name)
       return NULL;
    }
 #else
-
-   if (getenv (name) && strlen (getenv (name))) {
-      return bson_strdup (getenv (name));
+   char *const var = getenv (name);
+   if (var && strlen (var)) {
+      return bson_strdup (var);
    } else {
       return NULL;
    }
@@ -679,6 +753,22 @@ _mongoc_getenv (const char *name)
 #endif
 }
 
+bool
+_mongoc_setenv (const char *name, const char *value)
+{
+#ifdef _WIN32
+   return SetEnvironmentVariableA (name, value) != 0;
+#else
+
+   if (0 != setenv (name, value, 1)) {
+      return false;
+   }
+
+   return true;
+#endif
+}
+
+
 /* Nearly Divisionless (Algorithm 5): https://arxiv.org/abs/1805.10941 */
 static uint32_t
 _mongoc_rand_nduid32 (uint32_t s, uint32_t (*rand32) (void))
@@ -782,8 +872,7 @@ _mongoc_simple_rand_uint32_t (void)
 
    /* Ensure *all* bits are random, as RAND_MAX is only required to be at least
     * 32767 (2^15). */
-   return (((uint32_t) rand () & 0x7FFFu) << 0u) |
-          (((uint32_t) rand () & 0x7FFFu) << 15u) |
+   return (((uint32_t) rand () & 0x7FFFu) << 0u) | (((uint32_t) rand () & 0x7FFFu) << 15u) |
           (((uint32_t) rand () & 0x0003u) << 30u);
 }
 
@@ -794,10 +883,8 @@ _mongoc_simple_rand_uint64_t (void)
 
    /* Ensure *all* bits are random, as RAND_MAX is only required to be at least
     * 32767 (2^15). */
-   return (((uint64_t) rand () & 0x7FFFu) << 0u) |
-          (((uint64_t) rand () & 0x7FFFu) << 15u) |
-          (((uint64_t) rand () & 0x7FFFu) << 30u) |
-          (((uint64_t) rand () & 0x7FFFu) << 45u) |
+   return (((uint64_t) rand () & 0x7FFFu) << 0u) | (((uint64_t) rand () & 0x7FFFu) << 15u) |
+          (((uint64_t) rand () & 0x7FFFu) << 30u) | (((uint64_t) rand () & 0x7FFFu) << 45u) |
           (((uint64_t) rand () & 0x0003u) << 60u);
 }
 
@@ -821,8 +908,7 @@ _mongoc_rand_uint64_t (uint64_t min, uint64_t max, uint64_t (*rand) (void))
 
 #if SIZE_MAX == UINT64_MAX
 
-BSON_STATIC_ASSERT2 (_mongoc_simple_rand_size_t,
-                     sizeof (size_t) == sizeof (uint64_t));
+BSON_STATIC_ASSERT2 (_mongoc_simple_rand_size_t, sizeof (size_t) == sizeof (uint64_t));
 
 size_t
 _mongoc_simple_rand_size_t (void)
@@ -831,19 +917,17 @@ _mongoc_simple_rand_size_t (void)
 }
 
 size_t
-_mongoc_rand_size_t (size_t min, size_t max, size_t (*rand) (void))
+_mongoc_rand_size_t (size_t min, size_t max)
 {
    BSON_ASSERT (min <= max);
    BSON_ASSERT (min != 0u || max != UINT64_MAX);
 
-   return _mongoc_rand_java64 (max - min + 1u, (uint64_t (*) (void)) rand) +
-          min;
+   return _mongoc_rand_java64 (max - min + 1u, &_mongoc_simple_rand_uint64_t) + min;
 }
 
 #elif SIZE_MAX == UINT32_MAX
 
-BSON_STATIC_ASSERT2 (_mongoc_simple_rand_size_t,
-                     sizeof (size_t) == sizeof (uint32_t));
+BSON_STATIC_ASSERT2 (_mongoc_simple_rand_size_t, sizeof (size_t) == sizeof (uint32_t));
 
 size_t
 _mongoc_simple_rand_size_t (void)
@@ -852,26 +936,22 @@ _mongoc_simple_rand_size_t (void)
 }
 
 size_t
-_mongoc_rand_size_t (size_t min, size_t max, size_t (*rand) (void))
+_mongoc_rand_size_t (size_t min, size_t max)
 {
    BSON_ASSERT (min <= max);
    BSON_ASSERT (min != 0u || max != UINT32_MAX);
 
-   return _mongoc_rand_nduid32 (max - min + 1u, (uint32_t (*) (void)) rand) +
-          min;
+   return _mongoc_rand_nduid32 (max - min + 1u, &_mongoc_simple_rand_uint32_t) + min;
 }
 
 #else
 
-#error \
-   "Implementation of _mongoc_simple_rand_size_t() requires size_t be exactly 32-bit or 64-bit"
+#error "Implementation of _mongoc_simple_rand_size_t() requires size_t be exactly 32-bit or 64-bit"
 
 #endif
 
 bool
-_mongoc_iter_document_as_bson (const bson_iter_t *iter,
-                               bson_t *bson,
-                               bson_error_t *error)
+_mongoc_iter_document_as_bson (const bson_iter_t *iter, bson_t *bson, bson_error_t *error)
 {
    uint32_t len;
    const uint8_t *data;
@@ -897,3 +977,46 @@ _mongoc_iter_document_as_bson (const bson_iter_t *iter,
 
    return true;
 }
+
+uint8_t *
+hex_to_bin (const char *hex, uint32_t *len)
+{
+   uint8_t *out;
+
+   const size_t hex_len = strlen (hex);
+   if (hex_len % 2u != 0u) {
+      return NULL;
+   }
+
+   BSON_ASSERT (mcommon_in_range_unsigned (uint32_t, hex_len / 2u));
+
+   *len = (uint32_t) (hex_len / 2u);
+   out = bson_malloc0 (*len);
+
+   for (uint32_t i = 0; i < hex_len; i += 2u) {
+      uint32_t hex_char;
+
+      if (1 != sscanf (hex + i, "%2x", &hex_char)) {
+         bson_free (out);
+         return NULL;
+      }
+
+      BSON_ASSERT (mcommon_in_range_unsigned (uint8_t, hex_char));
+      out[i / 2u] = (uint8_t) hex_char;
+   }
+   return out;
+}
+
+char *
+bin_to_hex (const uint8_t *bin, uint32_t len)
+{
+   char *out = bson_malloc0 (2u * len + 1u);
+
+   for (uint32_t i = 0u; i < len; i++) {
+      // Expect no truncation.
+      int req = bson_snprintf (out + (2u * i), 3, "%02x", bin[i]);
+      BSON_ASSERT (req < 3);
+   }
+
+   return out;
+}
