@@ -1,5 +1,5 @@
 /*
- * Copyright 2015 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,16 +14,13 @@
  * limitations under the License.
  */
 
-
-#if !defined(MONGOC_INSIDE) && !defined(MONGOC_COMPILATION)
-#error "Only <mongoc.h> can be included directly."
-#endif
+#include "mongoc-prelude.h"
 
 
 #ifndef MONGOC_VERSION_FUNCTIONS_H
 #define MONGOC_VERSION_FUNCTIONS_H
 
-#include <bson.h> /* for "bool" */
+#include <bson/bson.h> /* for "bool" */
 
 #include "mongoc-macros.h"
 
@@ -38,9 +35,7 @@ mongoc_get_micro_version (void);
 MONGOC_EXPORT (const char *)
 mongoc_get_version (void);
 MONGOC_EXPORT (bool)
-mongoc_check_version (int required_major,
-                      int required_minor,
-                      int required_micro);
+mongoc_check_version (int required_major, int required_minor, int required_micro);
 
 BSON_END_DECLS
 
