@@ -1,5 +1,5 @@
 /*
- * Copyright 2013 MongoDB, Inc.
+ * Copyright 2009-present MongoDB, Inc.
  *
  * Licensed under the Apache License, Version 2.0 (the "License");
  * you may not use this file except in compliance with the License.
@@ -14,14 +14,12 @@
  * limitations under the License.
  */
 
+#include "mongoc-prelude.h"
+
 #ifndef MONGOC_WRITE_CONCERN_PRIVATE_H
 #define MONGOC_WRITE_CONCERN_PRIVATE_H
 
-#if !defined(MONGOC_COMPILATION)
-#error "Only <mongoc.h> can be included directly."
-#endif
-
-#include <bson.h>
+#include <bson/bson.h>
 
 
 BSON_BEGIN_DECLS
@@ -35,7 +33,7 @@ struct _mongoc_write_concern_t {
    int8_t fsync_; /* deprecated */
    int8_t journal;
    int32_t w;
-   int32_t wtimeout;
+   int64_t wtimeout;
    char *wtag;
    bool frozen;
    bson_t compiled;
@@ -44,8 +42,7 @@ struct _mongoc_write_concern_t {
 
 
 mongoc_write_concern_t *
-_mongoc_write_concern_new_from_iter (const bson_iter_t *iter,
-                                     bson_error_t *error);
+_mongoc_write_concern_new_from_iter (const bson_iter_t *iter, bson_error_t *error);
 const bson_t *
 _mongoc_write_concern_get_bson (mongoc_write_concern_t *write_concern);
 bool
